; Original MOD file: beast.mod
; Original MOD name: "Beast-Playtune2     "
; ASM file created by MOD2PSG V1.3 by Martin Konrad (mkon@gmx.de)
; Command line options: -nf 2 

; Constants
RAM_START = $C000

; PSGMOD variables
; (You can place these variables anywhere in RAM.)
PSGMOD_SONG_POSITION    = RAM_START
PSGMOD_PATTERN_POSITION = RAM_START + 1
PSGMOD_PATTERN_ADDRESS  = RAM_START + 2
PSGMOD_CURRENT_SPEED    = RAM_START + 4
PSGMOD_SPEED_COUNTER    = RAM_START + 5
PSGMOD_SONG_START       = RAM_START + 6
PSGMOD_VOL0             = RAM_START + 8
PSGMOD_VOL1             = RAM_START + 9
PSGMOD_VOL2             = RAM_START + 10
PSGMOD_INFO0            = RAM_START + 11
PSGMOD_INFO1            = RAM_START + 12
PSGMOD_INFO2            = RAM_START + 13
; Misc variables
VBLANK_DONE_FLAG        = RAM_START + 14

;==========================================
;=               Start code               =
;==========================================
.org $0000
  di
  im 1
  ld sp, $dff0
  jr START
;-------------------
; VBlank IRQ handler
.org $38
  exx
  ex af, af'
  in a, ($BF)

  ld hl, VBLANK_DONE_FLAG
  inc (HL)

  exx
  ex af, af'
  ei
  reti
;-------------------
; NMI
.org $66
  retn
;-------------------
START:
  call SETUP_FRAMES
  call SET_VDP_REGS_TABLE

;==========================================
;=               Song start               =
;==========================================
    ld hl, PSGMOD_SONG
  call PSGMOD_INITIATE_NEW_SONG
  ei
SONG_LOOP:
    ld d, 1
  call VWAIT

  call PSGMOD_PLAY_NEXT_NOTE

  jr SONG_LOOP
;==========================================
;=              Program end               =
;==========================================

;==========================================
;=            PSG MOD routines            =
;==========================================
; INPUT: HL = address of song
PSGMOD_INITIATE_NEW_SONG:
  ld a, 0
  ld (PSGMOD_SONG_POSITION), a
  ld a, 64
  ld (PSGMOD_PATTERN_POSITION), a
  ld a, 6
  ld (PSGMOD_CURRENT_SPEED), a
  ld (PSGMOD_SPEED_COUNTER), a
  ld a, 15
  ld (PSGMOD_VOL0), a
  ld (PSGMOD_VOL1), a
  ld (PSGMOD_VOL2), a
  ld a, l
  ld (PSGMOD_SONG_START), a
  ld a, h
  ld (PSGMOD_SONG_START + 1), a
  ld ix, (PSGMOD_SONG_START)
  ld a, (IX)
  ld l, a
  ld h, 0
  call HL_512
  ld bc, 128
  add hl, bc
  ld bc, (PSGMOD_SONG_START)
  add hl, bc
  ld a, l
  ld (PSGMOD_PATTERN_ADDRESS), a
  ld a, h
  ld (PSGMOD_PATTERN_ADDRESS+1), a
  ret

PSGMOD_PLAY_NEXT_NOTE:
  ld hl, PSGMOD_SPEED_COUNTER
  dec (HL)
  ret NZ

; Channel 0
    ld ix, (PSGMOD_PATTERN_ADDRESS)
    ld d, 144
    ld hl, PSGMOD_VOL0
  call PSGMOD_SET_VOLUME
    ld hl, PSGMOD_INFO0
    ld d, 128
  call PSGMOD_SET_FREQUENCY

; Channel 1
    ld ix, (PSGMOD_PATTERN_ADDRESS)
    inc ix
    inc ix
    ld d, 176
    ld hl, PSGMOD_VOL1
  call PSGMOD_SET_VOLUME
    ld hl, PSGMOD_INFO1
    ld d, 160
  call PSGMOD_SET_FREQUENCY

; Channel 2
    ld ix, (PSGMOD_PATTERN_ADDRESS)
    inc ix
    inc ix
    inc ix
    inc ix
    ld d, 208
    ld hl, PSGMOD_VOL2
  call PSGMOD_SET_VOLUME
    ld hl, PSGMOD_INFO2
    ld d, 192
  call PSGMOD_SET_FREQUENCY

; Channel 3
  ld hl, (PSGMOD_PATTERN_ADDRESS)
  ld bc, 6
  add hl, bc
  ld b, (HL)

; Set volume of channel 3
  ld a, b
  and 15
  add a, 240
  out ($7F), a

; Set frequeny of channel 3
  ld a, b
  srl a
  srl a
  srl a
  srl a
  add a, 228
  out ($7F), a

; Set speed
  ld hl, (PSGMOD_PATTERN_ADDRESS)
  ld bc, 7
  add hl, bc
  ld c, (HL)
  ld a, c
  and 128
  jr Z, PSGMOD_SET_SPEED
  ld a, 1
  ld (PSGMOD_PATTERN_POSITION), a
PSGMOD_SET_SPEED:
  ld a, c
  and 127
  ld (PSGMOD_CURRENT_SPEED), a
PSGMOD_DONT_SET_SPEED:
  ld a, (PSGMOD_CURRENT_SPEED)
  ld (PSGMOD_SPEED_COUNTER), a

; Next note
  ld hl, (PSGMOD_PATTERN_ADDRESS)
  ld bc, 8
  add hl, bc
  ld (PSGMOD_PATTERN_ADDRESS), hl

  ld hl, PSGMOD_PATTERN_POSITION
  dec (HL)
  ret NZ
  ld a, 64
  ld (PSGMOD_PATTERN_POSITION), a
  ld hl, PSGMOD_SONG_POSITION
  inc (HL)

  call PSGMOD_GET_PATTERN_NUMBER
  bit 7, d
  jr Z, PSGMOD_END_NOT_REACHED

  ld a, d
  and 127
  ld (PSGMOD_SONG_POSITION), a
  call PSGMOD_GET_PATTERN_NUMBER
PSGMOD_END_NOT_REACHED:
  ld h, 0
  ld l, d
  call HL_512
  ld bc, 128
  add hl, bc
  ld bc, (PSGMOD_SONG_START)
  add hl, bc
  ld a, l
  ld (PSGMOD_PATTERN_ADDRESS), a
  ld a, h
  ld (PSGMOD_PATTERN_ADDRESS+1), a
  ret

;==========================================
;=       PSG MOD internal routines        =
;==========================================
PSGMOD_SET_VOLUME:
  ld a, (IX)
  and 15
  cp 15
  jr Z, PSGMOD_FADE_VOL
  ld (HL), a
  add a, d
  out ($7F), a
  ret
PSGMOD_FADE_VOL:
  push hl
  ld bc, 3
  add hl, bc
  ld a, (HL)
  pop hl
  cp 0
  jr Z, PSGMOD_NO_FADE
  ld a, (HL)
  cp 15
  ret Z
  inc a
  ld (HL), a
  add a, d
  out ($7F), a
  ret
PSGMOD_NO_FADE:
  ld a, d
  add a, 15
  out ($7F), a
  ret
PSGMOD_SET_FREQUENCY:
  ld a, (IX)
  and 15
  cp 15
  ret Z
  ld a, (IX)
  srl a
  srl a
  srl a
  srl a
  add a, d
  out ($7F), a
  inc ix
  ld a, (IX)
  out ($7F), a
  bit 6, a
  jr NZ, PSGMOD_SET_FADE_BIT
  ld a, 0
  ld (HL), a
  ret
PSGMOD_SET_FADE_BIT:
  ld a, 1
  ld (HL), a
  ret

PSGMOD_GET_PATTERN_NUMBER:
  ld a, (PSGMOD_SONG_POSITION)
  ld hl, (PSGMOD_SONG_START)
  ld c, a
  ld b, 0
  add hl, bc
  ld d, (HL)
  ret

;==========================================
;=             Misc routines              =
;==========================================
HL_512:
  add hl, hl
  add hl, hl
  add hl, hl
  add hl, hl
  add hl, hl
  add hl, hl
  add hl, hl
  add hl, hl
  add hl, hl
  ret

VWAIT:
  ld a, 0
  ld (VBLANK_DONE_FLAG), a
VWAIT_LOOP:
  ld a, (VBLANK_DONE_FLAG)
  cp d
  ret Z
  jr VWAIT_LOOP

SETUP_FRAMES:
  ld a, 0
  ld ($FFFC), a
  ld ($FFFD), a
  ld a, 1
  ld ($FFFE), a
  ld a, 2
  ld ($FFFF), a
  ret

SET_VDP_REGS_TABLE:
  ld hl, VDP_REGS_TABLE
  ld b, $0f
  ld c, $80
VDP_REGS_LOOP:
  ld a, (HL)
  inc hl
  out ($bf), a
  ld a, c
  inc c
  out ($bf), a
  dec b
  jr NZ, VDP_REGS_LOOP
  ret

VDP_REGS_TABLE:
   .db $06, $60, $FF, $FF, $FF, $FF, $00, $00, $00, $00, $FF, $00, $00, $00, $00, $00

;==========================================
;=               Song data                =
;==========================================

PSGMOD_SONG:

PSGMOD_PATTERN_ORDER:
.db 0,1,0,1,2,3,4,5
.db 6,7,6,8,9,10,11,12
.db 13,14,13,15,16,17,18,19
.db 20,21,20,22,23,24,25,26
.db 128,0,0,0,0,0,0,0
.db 0,0,0,0,0,0,0,0
.db 0,0,0,0,0,0,0,0
.db 0,0,0,0,0,0,0,0
.db 0,0,0,0,0,0,0,0
.db 0,0,0,0,0,0,0,0
.db 0,0,0,0,0,0,0,0
.db 0,0,0,0,0,0,0,0
.db 0,0,0,0,0,0,0,0
.db 0,0,0,0,0,0,0,0
.db 0,0,0,0,0,0,0,0
.db 0,0,0,0,0,0,0,0

PSGMOD_PATTERN_DATA:
; PATTERN 0:
.dw 2962,1986,4467,769,15,15,15,783,
.dw 15,15,15,783,15,15,15,783,
.dw 2802,15,2807,783,15,15,15,783,
.dw 15,15,2807,783,15,15,15,783,
.dw 2962,1986,4467,783,15,15,15,783,
.dw 15,15,15,783,15,15,15,783,
.dw 2802,15,2807,783,15,15,15,783,
.dw 2962,15,2807,783,15,15,15,783,
.dw 15,1986,4467,783,15,15,15,783,
.dw 2802,15,15,783,15,15,15,783,
.dw 15,15,2807,783,15,15,15,783,
.dw 2962,15,2807,783,15,15,15,783,
.dw 2962,1986,4467,783,15,15,15,783,
.dw 15,15,15,783,15,15,15,783,
.dw 2802,15,2807,783,15,15,15,783,
.dw 15,15,2807,783,15,15,15,783,
.dw 2962,1986,4467,783,15,15,15,783,
.dw 15,15,15,783,15,15,15,783,
.dw 2802,15,2807,783,15,15,15,783,
.dw 15,15,2807,783,15,15,15,783,
.dw 2962,1986,4467,783,15,15,15,783,
.dw 15,15,15,783,15,15,15,783,
.dw 2802,15,2807,783,15,15,15,783,
.dw 2962,15,2807,783,15,15,15,783,
.dw 15,1986,4467,783,15,15,15,783,
.dw 2802,15,15,783,15,15,15,783,
.dw 15,15,2807,783,15,15,15,783,
.dw 2962,2962,2807,783,15,15,15,783,
.dw 2962,2962,4467,783,15,15,15,783,
.dw 15,2962,15,783,15,15,15,783,
.dw 2802,2962,2807,769,15,15,15,783,
.dw 15,2962,2807,783,15,15,15,783,
; PATTERN 1:
.dw 2642,1986,4467,769,15,15,15,783,
.dw 15,15,15,783,15,15,15,783,
.dw 3970,15,2807,783,15,15,15,783,
.dw 15,15,2807,783,15,15,15,783,
.dw 2642,1986,4467,783,15,15,15,783,
.dw 15,15,15,783,15,15,15,783,
.dw 3970,15,2807,783,15,15,15,783,
.dw 2642,15,2807,783,15,15,15,783,
.dw 15,1986,4467,783,15,15,15,783,
.dw 3970,15,15,783,15,15,15,783,
.dw 15,15,2807,783,15,15,15,783,
.dw 2498,15,2807,783,15,15,15,783,
.dw 2498,1986,4467,783,15,15,15,783,
.dw 2498,15,15,783,15,15,15,783,
.dw 2642,15,2807,783,15,15,15,783,
.dw 15,15,2807,783,15,15,15,783,
.dw 2642,1986,4467,783,15,15,15,783,
.dw 15,15,15,783,15,15,15,783,
.dw 3970,15,2807,783,15,15,15,783,
.dw 15,15,2807,783,15,15,15,783,
.dw 2642,1986,4467,783,15,15,15,783,
.dw 15,15,15,783,15,15,15,783,
.dw 3970,15,2807,783,15,15,15,783,
.dw 2642,15,2807,783,15,15,15,783,
.dw 15,1986,4467,783,15,15,15,783,
.dw 3970,15,15,783,15,15,15,783,
.dw 15,15,2807,783,15,15,15,783,
.dw 2498,1874,2807,783,15,15,15,783,
.dw 2498,1874,1986,783,15,15,15,783,
.dw 2498,1874,15,783,15,15,15,783,
.dw 2642,1874,1986,769,15,15,15,783,
.dw 15,1874,1986,783,15,15,15,783,
; PATTERN 2:
.dw 2962,1986,4467,769,15,15,15,783,
.dw 15,15,15,783,15,15,15,783,
.dw 1490,15,2807,783,15,15,15,783,
.dw 15,15,2807,783,15,15,15,783,
.dw 2962,1986,4467,783,15,15,15,783,
.dw 1986,15,15,783,15,15,15,783,
.dw 15,15,2807,783,15,15,15,783,
.dw 2962,15,2807,783,15,15,15,783,
.dw 1874,1986,4467,783,15,15,15,783,
.dw 15,15,15,783,15,15,15,783,
.dw 2962,15,2807,783,15,15,15,783,
.dw 1986,15,2807,783,15,15,15,783,
.dw 15,1986,4467,783,15,15,15,783,
.dw 1666,15,15,783,15,15,15,783,
.dw 1874,15,2807,783,15,15,15,783,
.dw 1986,15,2807,783,15,15,15,783,
.dw 2962,1986,4467,783,15,15,15,783,
.dw 15,15,15,783,15,15,15,783,
.dw 1490,15,2807,783,15,15,15,783,
.dw 15,15,2807,783,15,15,15,783,
.dw 2962,1986,4467,783,15,15,15,783,
.dw 1986,15,15,783,15,15,15,783,
.dw 15,15,2807,783,15,15,15,783,
.dw 2962,15,2807,783,15,15,15,783,
.dw 1874,1986,4467,783,15,15,15,783,
.dw 15,15,15,783,15,15,15,783,
.dw 2962,15,2807,783,15,15,15,783,
.dw 1986,2962,2807,783,15,15,15,783,
.dw 15,2962,4467,783,15,15,15,783,
.dw 2498,2962,15,783,15,15,15,783,
.dw 2642,2962,2807,769,15,15,15,783,
.dw 2962,2962,2807,783,15,15,15,783,
; PATTERN 3:
.dw 3330,1986,4467,769,15,15,15,783,
.dw 15,15,15,783,15,15,15,783,
.dw 1986,15,2807,783,15,15,15,783,
.dw 15,15,2807,783,15,15,15,783,
.dw 3330,1986,4467,783,15,15,15,783,
.dw 2642,15,15,783,15,15,15,783,
.dw 15,15,2807,783,15,15,15,783,
.dw 3330,15,2807,783,15,15,15,783,
.dw 2498,1986,4467,783,15,15,15,783,
.dw 15,15,15,783,15,15,15,783,
.dw 3330,15,2807,783,15,15,15,783,
.dw 2642,15,2807,783,15,15,15,783,
.dw 15,1986,4467,783,15,15,15,783,
.dw 2226,15,15,783,15,15,15,783,
.dw 2498,15,2807,783,15,15,15,783,
.dw 2642,15,2807,783,15,15,15,783,
.dw 3330,1986,4467,783,15,15,15,783,
.dw 15,15,15,783,15,15,15,783,
.dw 1986,15,2807,783,15,15,15,783,
.dw 15,15,2807,783,15,15,15,783,
.dw 3330,1986,4467,783,15,15,15,783,
.dw 2642,15,15,783,15,15,15,783,
.dw 15,15,2807,783,15,15,15,783,
.dw 3330,15,2807,783,15,15,15,783,
.dw 2498,1986,4467,783,15,15,15,783,
.dw 15,15,15,783,15,15,15,783,
.dw 3330,15,2807,783,15,15,15,783,
.dw 2642,1874,2807,783,15,15,15,783,
.dw 15,1874,1986,783,15,15,15,783,
.dw 1666,1874,15,783,15,15,15,783,
.dw 1762,1874,1986,769,15,15,15,783,
.dw 1986,1874,1986,783,15,15,15,783,
; PATTERN 4:
.dw 19346,1986,4467,769,15,15,15,783,
.dw 15,15,15,783,15,15,15,783,
.dw 17874,15,2807,783,15,15,15,783,
.dw 15,15,2807,783,15,15,15,783,
.dw 19346,1986,4467,783,15,15,15,783,
.dw 18370,15,15,783,15,15,15,783,
.dw 15,15,2807,783,15,15,15,783,
.dw 19346,15,2807,783,15,15,15,783,
.dw 18258,1986,4467,783,15,15,15,783,
.dw 15,15,15,783,15,15,15,783,
.dw 19346,15,2807,783,15,15,15,783,
.dw 18370,15,2807,783,15,15,15,783,
.dw 15,1986,4467,783,15,15,15,783,
.dw 18050,15,15,783,15,15,15,783,
.dw 18258,15,2807,783,15,15,15,783,
.dw 18370,15,2807,783,15,15,15,783,
.dw 19346,1986,4467,783,15,15,15,783,
.dw 15,15,15,783,15,15,15,783,
.dw 17874,15,2807,783,15,15,15,783,
.dw 15,15,2807,783,15,15,15,783,
.dw 19346,1986,4467,783,15,15,15,783,
.dw 18370,15,15,783,15,15,15,783,
.dw 15,15,2807,783,15,15,15,783,
.dw 19346,15,2807,783,15,15,15,783,
.dw 18258,1986,4467,783,15,15,15,783,
.dw 15,15,15,783,15,15,15,783,
.dw 19346,15,2807,783,15,15,15,783,
.dw 18370,2962,2807,783,15,15,15,783,
.dw 15,2962,4467,783,15,15,15,783,
.dw 18882,2962,15,783,15,15,15,783,
.dw 19026,2962,2807,769,15,15,15,783,
.dw 19346,2962,2807,783,15,15,15,783,
; PATTERN 5:
.dw 19714,1986,4467,769,15,15,15,783,
.dw 15,15,15,783,15,15,15,783,
.dw 18370,15,2807,783,15,15,15,783,
.dw 15,15,2807,783,15,15,15,783,
.dw 19714,1986,4467,783,15,15,15,783,
.dw 19026,15,15,783,15,15,15,783,
.dw 15,15,2807,783,15,15,15,783,
.dw 19714,15,2807,783,15,15,15,783,
.dw 18882,1986,4467,783,15,15,15,783,
.dw 15,15,15,783,15,15,15,783,
.dw 19714,15,2807,783,15,15,15,783,
.dw 19026,15,2807,783,15,15,15,783,
.dw 15,1986,4467,783,15,15,15,783,
.dw 18610,15,15,783,15,15,15,783,
.dw 18882,15,2807,783,15,15,15,783,
.dw 19026,15,2807,783,15,15,15,783,
.dw 19714,1986,4467,783,15,15,15,783,
.dw 15,15,15,783,15,15,15,783,
.dw 18370,15,2807,783,15,15,15,783,
.dw 15,15,2807,783,15,15,15,783,
.dw 19714,1986,4467,783,15,15,15,783,
.dw 19026,15,15,783,15,15,15,783,
.dw 15,15,2807,783,15,15,15,783,
.dw 19714,15,2807,783,15,15,15,783,
.dw 18882,1986,4467,783,15,15,15,783,
.dw 15,15,15,783,15,15,15,783,
.dw 19714,15,2807,783,15,15,15,783,
.dw 19026,1874,2807,783,15,15,15,783,
.dw 15,1874,1986,783,15,15,15,783,
.dw 18050,1874,15,783,15,15,15,783,
.dw 18258,1874,1986,769,15,15,15,783,
.dw 18370,1874,1986,783,15,15,15,783,
; PATTERN 6:
.dw 2802,1874,4467,769,15,15,15,783,
.dw 15,15,15,783,15,15,15,783,
.dw 2642,15,2807,783,15,15,15,783,
.dw 15,15,2807,783,15,15,15,783,
.dw 2802,1874,4467,783,15,15,15,783,
.dw 15,15,15,783,15,15,15,783,
.dw 2642,15,2807,783,15,15,15,783,
.dw 2802,15,2807,783,15,15,15,783,
.dw 15,1874,4467,783,15,15,15,783,
.dw 2642,15,15,783,15,15,15,783,
.dw 15,15,2807,783,15,15,15,783,
.dw 2802,15,2807,783,15,15,15,783,
.dw 2802,1874,4467,783,15,15,15,783,
.dw 15,15,15,783,15,15,15,783,
.dw 2642,15,2807,783,15,15,15,783,
.dw 15,15,2807,783,15,15,15,783,
.dw 2802,1874,4467,783,15,15,15,783,
.dw 15,15,15,783,15,15,15,783,
.dw 2642,15,2807,783,15,15,15,783,
.dw 15,15,2807,783,15,15,15,783,
.dw 2802,1874,4467,783,15,15,15,783,
.dw 15,15,15,783,15,15,15,783,
.dw 2642,15,2807,783,15,15,15,783,
.dw 2802,15,2807,783,15,15,15,783,
.dw 15,1874,4467,783,15,15,15,783,
.dw 2642,15,15,783,15,15,15,783,
.dw 15,15,2807,783,15,15,15,783,
.dw 2802,2802,2807,783,15,15,15,783,
.dw 2802,2802,4467,783,15,15,15,783,
.dw 15,2802,15,783,15,15,15,783,
.dw 2642,2802,2807,769,15,15,15,783,
.dw 15,2802,2807,783,15,15,15,783,
; PATTERN 7:
.dw 2498,1874,4467,769,15,15,15,783,
.dw 15,15,15,783,15,15,15,783,
.dw 3746,15,2807,783,15,15,15,783,
.dw 15,15,2807,783,15,15,15,783,
.dw 2498,1874,4467,783,15,15,15,783,
.dw 15,15,15,783,15,15,15,783,
.dw 3746,15,2807,783,15,15,15,783,
.dw 2498,15,2807,783,15,15,15,783,
.dw 15,1874,4467,783,15,15,15,783,
.dw 3746,15,15,783,15,15,15,783,
.dw 15,15,2807,783,15,15,15,783,
.dw 2354,15,2807,783,15,15,15,783,
.dw 2354,1874,4467,783,15,15,15,783,
.dw 2354,15,15,783,15,15,15,783,
.dw 2498,15,2807,783,15,15,15,783,
.dw 15,15,2807,783,15,15,15,783,
.dw 2498,1874,4467,783,15,15,15,783,
.dw 15,15,15,783,15,15,15,783,
.dw 3746,15,2807,783,15,15,15,783,
.dw 15,15,2807,783,15,15,15,783,
.dw 2498,1874,4467,783,15,15,15,783,
.dw 15,15,15,783,15,15,15,783,
.dw 3746,15,2807,783,15,15,15,783,
.dw 2498,15,2807,783,15,15,15,783,
.dw 15,1874,4467,783,15,15,15,783,
.dw 3746,15,15,783,15,15,15,783,
.dw 15,15,2807,783,15,15,15,783,
.dw 2498,1762,2807,783,15,15,15,783,
.dw 2498,1762,1986,783,15,15,15,783,
.dw 15,1762,15,783,15,15,15,783,
.dw 3746,1762,1986,769,15,15,15,783,
.dw 15,1762,1986,783,15,15,15,783,
; PATTERN 8:
.dw 2498,1874,4467,769,15,15,15,783,
.dw 15,15,15,783,15,15,15,783,
.dw 2354,15,2807,783,15,15,15,783,
.dw 15,15,2807,783,15,15,15,783,
.dw 2498,1874,4467,783,15,15,15,783,
.dw 15,15,15,783,15,15,15,783,
.dw 2354,15,2807,783,15,15,15,783,
.dw 2498,15,2807,783,15,15,15,783,
.dw 15,1874,4467,783,15,15,15,783,
.dw 2354,15,15,783,15,15,15,783,
.dw 15,15,2807,783,15,15,15,783,
.dw 2498,15,2807,783,15,15,15,783,
.dw 2498,1874,4467,783,15,15,15,783,
.dw 15,15,15,783,15,15,15,783,
.dw 2354,15,2807,783,15,15,15,783,
.dw 15,15,2807,783,15,15,15,783,
.dw 2498,1874,4467,783,15,15,15,783,
.dw 15,15,15,783,15,15,15,783,
.dw 2354,15,2807,783,15,15,15,783,
.dw 15,15,2807,783,15,15,15,783,
.dw 2498,1874,4467,783,15,15,15,783,
.dw 15,15,15,783,15,15,15,783,
.dw 2354,15,2807,783,15,15,15,783,
.dw 2498,15,2807,783,15,15,15,783,
.dw 15,1874,4467,783,15,15,15,783,
.dw 2354,15,15,783,15,15,15,783,
.dw 15,15,2807,783,15,15,15,783,
.dw 2354,1762,2807,783,15,15,15,783,
.dw 2354,1762,1986,783,15,15,15,783,
.dw 2354,1762,15,783,15,15,15,783,
.dw 2498,1762,1986,769,15,15,15,783,
.dw 15,1762,1986,783,15,15,15,783,
; PATTERN 9:
.dw 2802,1874,4467,769,15,15,15,783,
.dw 15,15,15,783,15,15,15,783,
.dw 1394,15,2807,783,15,15,15,783,
.dw 15,15,2807,783,15,15,15,783,
.dw 2802,1874,4467,783,15,15,15,783,
.dw 1874,15,15,783,15,15,15,783,
.dw 15,15,2807,783,15,15,15,783,
.dw 2802,15,2807,783,15,15,15,783,
.dw 1762,1874,4467,783,15,15,15,783,
.dw 15,15,15,783,15,15,15,783,
.dw 2802,15,2807,783,15,15,15,783,
.dw 1874,15,2807,783,15,15,15,783,
.dw 15,1874,4467,783,15,15,15,783,
.dw 1570,15,15,783,15,15,15,783,
.dw 1762,15,2807,783,15,15,15,783,
.dw 1874,15,2807,783,15,15,15,783,
.dw 2802,1874,4467,783,15,15,15,783,
.dw 15,15,15,783,15,15,15,783,
.dw 1394,15,2807,783,15,15,15,783,
.dw 15,15,2807,783,15,15,15,783,
.dw 2802,1874,4467,783,15,15,15,783,
.dw 1874,15,15,783,15,15,15,783,
.dw 15,15,2807,783,15,15,15,783,
.dw 2802,15,2807,783,15,15,15,783,
.dw 1762,1874,4467,783,15,15,15,783,
.dw 15,15,15,783,15,15,15,783,
.dw 2802,15,2807,783,15,15,15,783,
.dw 1874,2802,2807,783,15,15,15,783,
.dw 15,2802,4467,783,15,15,15,783,
.dw 2354,2802,15,783,15,15,15,783,
.dw 2498,2802,2807,769,15,15,15,783,
.dw 2802,2802,2807,783,15,15,15,783,
; PATTERN 10:
.dw 3138,1874,4467,769,15,15,15,783,
.dw 15,15,15,783,15,15,15,783,
.dw 1874,15,2807,783,15,15,15,783,
.dw 15,15,2807,783,15,15,15,783,
.dw 3138,1874,4467,783,15,15,15,783,
.dw 2498,15,15,783,15,15,15,783,
.dw 15,15,2807,783,15,15,15,783,
.dw 3138,15,2807,783,15,15,15,783,
.dw 2354,1874,4467,783,15,15,15,783,
.dw 15,15,15,783,15,15,15,783,
.dw 3138,15,2807,783,15,15,15,783,
.dw 2498,15,2807,783,15,15,15,783,
.dw 15,1874,4467,783,15,15,15,783,
.dw 2098,15,15,783,15,15,15,783,
.dw 2354,15,2807,783,15,15,15,783,
.dw 2498,15,2807,783,15,15,15,783,
.dw 3138,1874,4467,783,15,15,15,783,
.dw 15,15,15,783,15,15,15,783,
.dw 1874,15,2807,783,15,15,15,783,
.dw 15,15,2807,783,15,15,15,783,
.dw 3138,1874,4467,783,15,15,15,783,
.dw 2498,15,15,783,15,15,15,783,
.dw 15,15,2807,783,15,15,15,783,
.dw 3138,15,2807,783,15,15,15,783,
.dw 2354,1874,4467,783,15,15,15,783,
.dw 15,15,15,783,15,15,15,783,
.dw 3138,15,2807,783,15,15,15,783,
.dw 2498,1762,2807,783,15,15,15,783,
.dw 15,1762,1986,783,15,15,15,783,
.dw 1570,1762,15,783,15,15,15,783,
.dw 1666,1762,1986,769,15,15,15,783,
.dw 1874,1762,1986,783,15,15,15,783,
; PATTERN 11:
.dw 19186,1874,4467,769,15,15,15,783,
.dw 15,15,15,783,15,15,15,783,
.dw 17778,15,2807,783,15,15,15,783,
.dw 15,15,2807,783,15,15,15,783,
.dw 19186,1874,4467,783,15,15,15,783,
.dw 18258,15,15,783,15,15,15,783,
.dw 15,15,2807,783,15,15,15,783,
.dw 19186,15,2807,783,15,15,15,783,
.dw 18146,1874,4467,783,15,15,15,783,
.dw 15,15,15,783,15,15,15,783,
.dw 19186,15,2807,783,15,15,15,783,
.dw 18258,15,2807,783,15,15,15,783,
.dw 15,1874,4467,783,15,15,15,783,
.dw 17954,15,15,783,15,15,15,783,
.dw 18146,15,2807,783,15,15,15,783,
.dw 18258,15,2807,783,15,15,15,783,
.dw 19186,1874,4467,783,15,15,15,783,
.dw 15,15,15,783,15,15,15,783,
.dw 17778,15,2807,783,15,15,15,783,
.dw 15,15,2807,783,15,15,15,783,
.dw 19186,1874,4467,783,15,15,15,783,
.dw 18258,15,15,783,15,15,15,783,
.dw 15,15,2807,783,15,15,15,783,
.dw 19186,15,2807,783,15,15,15,783,
.dw 18146,1874,4467,783,15,15,15,783,
.dw 15,15,15,783,15,15,15,783,
.dw 19186,15,2807,783,15,15,15,783,
.dw 18258,2802,2807,783,15,15,15,783,
.dw 15,2802,4467,783,15,15,15,783,
.dw 18738,2802,15,783,15,15,15,783,
.dw 18882,2802,2807,769,15,15,15,783,
.dw 19186,2802,2807,783,15,15,15,783,
; PATTERN 12:
.dw 19522,1874,4467,769,15,15,15,783,
.dw 15,15,15,783,15,15,15,783,
.dw 18258,15,2807,783,15,15,15,783,
.dw 15,15,2807,783,15,15,15,783,
.dw 19522,1874,4467,783,15,15,15,783,
.dw 18882,15,15,783,15,15,15,783,
.dw 15,15,2807,783,15,15,15,783,
.dw 19522,15,2807,783,15,15,15,783,
.dw 18738,1874,4467,783,15,15,15,783,
.dw 15,15,15,783,15,15,15,783,
.dw 19522,15,2807,783,15,15,15,783,
.dw 18882,15,2807,783,15,15,15,783,
.dw 15,1874,4467,783,15,15,15,783,
.dw 18482,15,15,783,15,15,15,783,
.dw 18738,15,2807,783,15,15,15,783,
.dw 18882,15,2807,783,15,15,15,783,
.dw 19522,1874,4467,783,15,15,15,783,
.dw 15,15,15,783,15,15,15,783,
.dw 18258,15,2807,783,15,15,15,783,
.dw 15,15,2807,783,15,15,15,783,
.dw 19522,1874,4467,783,15,15,15,783,
.dw 18882,15,15,783,15,15,15,783,
.dw 15,15,2807,783,15,15,15,783,
.dw 19522,15,2807,783,15,15,15,783,
.dw 18738,1874,4467,783,15,15,15,783,
.dw 15,15,15,783,15,15,15,783,
.dw 19522,15,2807,783,15,15,15,783,
.dw 18882,1762,2807,783,15,15,15,783,
.dw 15,1762,1986,783,15,15,15,783,
.dw 17954,1762,15,783,15,15,15,783,
.dw 18050,1762,1986,769,15,15,15,783,
.dw 18258,1762,1986,783,15,15,15,783,
; PATTERN 13:
.dw 2642,1762,4467,769,15,15,15,783,
.dw 15,15,15,783,15,15,15,783,
.dw 2498,15,2807,783,15,15,15,783,
.dw 15,15,2807,783,15,15,15,783,
.dw 2642,1762,4467,783,15,15,15,783,
.dw 15,15,15,783,15,15,15,783,
.dw 2498,15,2807,783,15,15,15,783,
.dw 2642,15,2807,783,15,15,15,783,
.dw 15,1762,4467,783,15,15,15,783,
.dw 2498,15,15,783,15,15,15,783,
.dw 15,15,2807,783,15,15,15,783,
.dw 2642,15,2807,783,15,15,15,783,
.dw 2642,1762,4467,783,15,15,15,783,
.dw 15,15,15,783,15,15,15,783,
.dw 2498,15,2807,783,15,15,15,783,
.dw 15,15,2807,783,15,15,15,783,
.dw 2642,1762,4467,783,15,15,15,783,
.dw 15,15,15,783,15,15,15,783,
.dw 2498,15,2807,783,15,15,15,783,
.dw 15,15,2807,783,15,15,15,783,
.dw 2642,1762,4467,783,15,15,15,783,
.dw 15,15,15,783,15,15,15,783,
.dw 2498,15,2807,783,15,15,15,783,
.dw 2642,15,2807,783,15,15,15,783,
.dw 15,1762,4467,783,15,15,15,783,
.dw 2498,15,15,783,15,15,15,783,
.dw 15,15,2807,783,15,15,15,783,
.dw 2642,2642,2807,783,15,15,15,783,
.dw 2642,2642,4467,783,15,15,15,783,
.dw 15,2642,15,783,15,15,15,783,
.dw 2498,2642,2807,769,15,15,15,783,
.dw 15,2642,2807,783,15,15,15,783,
; PATTERN 14:
.dw 2354,1762,4467,769,15,15,15,783,
.dw 15,15,15,783,15,15,15,783,
.dw 3538,15,2807,783,15,15,15,783,
.dw 15,15,2807,783,15,15,15,783,
.dw 2354,1762,4467,783,15,15,15,783,
.dw 15,15,15,783,15,15,15,783,
.dw 3538,15,2807,783,15,15,15,783,
.dw 2354,15,2807,783,15,15,15,783,
.dw 15,1762,4467,783,15,15,15,783,
.dw 3538,15,15,783,15,15,15,783,
.dw 15,15,2807,783,15,15,15,783,
.dw 2226,15,2807,783,15,15,15,783,
.dw 2226,1762,4467,783,15,15,15,783,
.dw 2226,15,15,783,15,15,15,783,
.dw 2354,15,2807,783,15,15,15,783,
.dw 15,15,2807,783,15,15,15,783,
.dw 2354,1762,4467,783,15,15,15,783,
.dw 15,15,15,783,15,15,15,783,
.dw 3538,15,2807,783,15,15,15,783,
.dw 15,15,2807,783,15,15,15,783,
.dw 2354,1762,4467,783,15,15,15,783,
.dw 15,15,15,783,15,15,15,783,
.dw 3538,15,2807,783,15,15,15,783,
.dw 2354,15,2807,783,15,15,15,783,
.dw 15,1762,4467,783,15,15,15,783,
.dw 3538,15,15,783,15,15,15,783,
.dw 15,15,2807,783,15,15,15,783,
.dw 2354,1666,2807,783,15,15,15,783,
.dw 2354,1666,1986,783,15,15,15,783,
.dw 15,1666,15,783,15,15,15,783,
.dw 3538,1666,1986,769,15,15,15,783,
.dw 15,1666,1986,783,15,15,15,783,
; PATTERN 15:
.dw 2354,1762,4467,769,15,15,15,783,
.dw 15,15,15,783,15,15,15,783,
.dw 2226,15,2807,783,15,15,15,783,
.dw 15,15,2807,783,15,15,15,783,
.dw 2354,1762,4467,783,15,15,15,783,
.dw 15,15,15,783,15,15,15,783,
.dw 2226,15,2807,783,15,15,15,783,
.dw 2354,15,2807,783,15,15,15,783,
.dw 15,1762,4467,783,15,15,15,783,
.dw 2226,15,15,783,15,15,15,783,
.dw 15,15,2807,783,15,15,15,783,
.dw 2354,15,2807,783,15,15,15,783,
.dw 2354,1762,4467,783,15,15,15,783,
.dw 15,15,15,783,15,15,15,783,
.dw 2226,15,2807,783,15,15,15,783,
.dw 15,15,2807,783,15,15,15,783,
.dw 2354,1762,4467,783,15,15,15,783,
.dw 15,15,15,783,15,15,15,783,
.dw 2226,15,2807,783,15,15,15,783,
.dw 15,15,2807,783,15,15,15,783,
.dw 2354,1762,4467,783,15,15,15,783,
.dw 15,15,15,783,15,15,15,783,
.dw 2226,15,2807,783,15,15,15,783,
.dw 2354,15,2807,783,15,15,15,783,
.dw 15,1762,4467,783,15,15,15,783,
.dw 2226,15,15,783,15,15,15,783,
.dw 15,15,2807,783,15,15,15,783,
.dw 2226,1666,2807,783,15,15,15,783,
.dw 2226,1666,1986,783,15,15,15,783,
.dw 2226,1666,15,783,15,15,15,783,
.dw 2354,1666,1986,769,15,15,15,783,
.dw 15,1666,1986,783,15,15,15,783,
; PATTERN 16:
.dw 2642,1762,4467,769,15,15,15,783,
.dw 15,15,15,783,15,15,15,783,
.dw 1314,15,2807,783,15,15,15,783,
.dw 15,15,2807,783,15,15,15,783,
.dw 2642,1762,4467,783,15,15,15,783,
.dw 1762,15,15,783,15,15,15,783,
.dw 15,15,2807,783,15,15,15,783,
.dw 2642,15,2807,783,15,15,15,783,
.dw 1666,1762,4467,783,15,15,15,783,
.dw 15,15,15,783,15,15,15,783,
.dw 2642,15,2807,783,15,15,15,783,
.dw 1762,15,2807,783,15,15,15,783,
.dw 15,1762,4467,783,15,15,15,783,
.dw 1490,15,15,783,15,15,15,783,
.dw 1666,15,2807,783,15,15,15,783,
.dw 1762,15,2807,783,15,15,15,783,
.dw 2642,1762,4467,783,15,15,15,783,
.dw 15,15,15,783,15,15,15,783,
.dw 1314,15,2807,783,15,15,15,783,
.dw 15,15,2807,783,15,15,15,783,
.dw 2642,1762,4467,783,15,15,15,783,
.dw 1762,15,15,783,15,15,15,783,
.dw 15,15,2807,783,15,15,15,783,
.dw 2642,15,2807,783,15,15,15,783,
.dw 1666,1762,4467,783,15,15,15,783,
.dw 15,15,15,783,15,15,15,783,
.dw 2642,15,2807,783,15,15,15,783,
.dw 1762,2642,2807,783,15,15,15,783,
.dw 15,2642,4467,783,15,15,15,783,
.dw 2226,2642,15,783,15,15,15,783,
.dw 2354,2642,2807,769,15,15,15,783,
.dw 2642,2642,2807,783,15,15,15,783,
; PATTERN 17:
.dw 2962,1762,4467,769,15,15,15,783,
.dw 15,15,15,783,15,15,15,783,
.dw 1762,15,2807,783,15,15,15,783,
.dw 15,15,2807,783,15,15,15,783,
.dw 2962,1762,4467,783,15,15,15,783,
.dw 2354,15,15,783,15,15,15,783,
.dw 15,15,2807,783,15,15,15,783,
.dw 2962,15,2807,783,15,15,15,783,
.dw 2226,1762,4467,783,15,15,15,783,
.dw 15,15,15,783,15,15,15,783,
.dw 2962,15,2807,783,15,15,15,783,
.dw 2354,15,2807,783,15,15,15,783,
.dw 15,1762,4467,783,15,15,15,783,
.dw 1986,15,15,783,15,15,15,783,
.dw 2226,15,2807,783,15,15,15,783,
.dw 2354,15,2807,783,15,15,15,783,
.dw 2962,1762,4467,783,15,15,15,783,
.dw 15,15,15,783,15,15,15,783,
.dw 1762,15,2807,783,15,15,15,783,
.dw 15,15,2807,783,15,15,15,783,
.dw 2962,1762,4467,783,15,15,15,783,
.dw 2354,15,15,783,15,15,15,783,
.dw 15,15,2807,783,15,15,15,783,
.dw 2962,15,2807,783,15,15,15,783,
.dw 2226,1762,4467,783,15,15,15,783,
.dw 15,15,15,783,15,15,15,783,
.dw 2962,15,2807,783,15,15,15,783,
.dw 2354,1666,2807,783,15,15,15,783,
.dw 15,1666,1986,783,15,15,15,783,
.dw 1490,1666,15,783,15,15,15,783,
.dw 1570,1666,1986,769,15,15,15,783,
.dw 1762,1666,1986,783,15,15,15,783,
; PATTERN 18:
.dw 19026,1762,4467,769,15,15,15,783,
.dw 15,15,15,783,15,15,15,783,
.dw 17698,15,2807,783,15,15,15,783,
.dw 15,15,2807,783,15,15,15,783,
.dw 19026,1762,4467,783,15,15,15,783,
.dw 18146,15,15,783,15,15,15,783,
.dw 15,15,2807,783,15,15,15,783,
.dw 19026,15,2807,783,15,15,15,783,
.dw 18050,1762,4467,783,15,15,15,783,
.dw 15,15,15,783,15,15,15,783,
.dw 19026,15,2807,783,15,15,15,783,
.dw 18146,15,2807,783,15,15,15,783,
.dw 15,1762,4467,783,15,15,15,783,
.dw 17874,15,15,783,15,15,15,783,
.dw 18050,15,2807,783,15,15,15,783,
.dw 18146,15,2807,783,15,15,15,783,
.dw 19026,1762,4467,783,15,15,15,783,
.dw 15,15,15,783,15,15,15,783,
.dw 17698,15,2807,783,15,15,15,783,
.dw 15,15,2807,783,15,15,15,783,
.dw 19026,1762,4467,783,15,15,15,783,
.dw 18146,15,15,783,15,15,15,783,
.dw 15,15,2807,783,15,15,15,783,
.dw 19026,15,2807,783,15,15,15,783,
.dw 18050,1762,4467,783,15,15,15,783,
.dw 15,15,15,783,15,15,15,783,
.dw 19026,15,2807,783,15,15,15,783,
.dw 18146,2642,2807,783,15,15,15,783,
.dw 15,2642,4467,783,15,15,15,783,
.dw 18610,2642,15,783,15,15,15,783,
.dw 18738,2642,2807,769,15,15,15,783,
.dw 19026,2642,2807,783,15,15,15,783,
; PATTERN 19:
.dw 19346,1762,4467,769,15,15,15,783,
.dw 15,15,15,783,15,15,15,783,
.dw 18146,15,2807,783,15,15,15,783,
.dw 15,15,2807,783,15,15,15,783,
.dw 19346,1762,4467,783,15,15,15,783,
.dw 18738,15,15,783,15,15,15,783,
.dw 15,15,2807,783,15,15,15,783,
.dw 19346,15,2807,783,15,15,15,783,
.dw 18610,1762,4467,783,15,15,15,783,
.dw 15,15,15,783,15,15,15,783,
.dw 19346,15,2807,783,15,15,15,783,
.dw 18738,15,2807,783,15,15,15,783,
.dw 15,1762,4467,783,15,15,15,783,
.dw 18370,15,15,783,15,15,15,783,
.dw 18610,15,2807,783,15,15,15,783,
.dw 18738,15,2807,783,15,15,15,783,
.dw 19346,1762,4467,783,15,15,15,783,
.dw 15,15,15,783,15,15,15,783,
.dw 18146,15,2807,783,15,15,15,783,
.dw 15,15,2807,783,15,15,15,783,
.dw 19346,1762,4467,783,15,15,15,783,
.dw 18738,15,15,783,15,15,15,783,
.dw 15,15,2807,783,15,15,15,783,
.dw 19346,15,2807,783,15,15,15,783,
.dw 18610,1762,4467,783,15,15,15,783,
.dw 15,15,15,783,15,15,15,783,
.dw 19346,15,2807,783,15,15,15,783,
.dw 18738,1666,2807,783,15,15,15,783,
.dw 15,1666,1986,783,15,15,15,783,
.dw 17874,1666,15,783,15,15,15,783,
.dw 17954,1666,1986,769,15,15,15,783,
.dw 18146,1666,1986,783,15,15,15,783,
; PATTERN 20:
.dw 2498,1666,4467,769,15,15,15,783,
.dw 15,15,15,783,15,15,15,783,
.dw 2354,15,2807,783,15,15,15,783,
.dw 15,15,2807,783,15,15,15,783,
.dw 2498,1666,4467,783,15,15,15,783,
.dw 15,15,15,783,15,15,15,783,
.dw 2354,15,2807,783,15,15,15,783,
.dw 2498,15,2807,783,15,15,15,783,
.dw 15,1666,4467,783,15,15,15,783,
.dw 2354,15,15,783,15,15,15,783,
.dw 15,15,2807,783,15,15,15,783,
.dw 2498,15,2807,783,15,15,15,783,
.dw 2498,1666,4467,783,15,15,15,783,
.dw 15,15,15,783,15,15,15,783,
.dw 2354,15,2807,783,15,15,15,783,
.dw 15,15,2807,783,15,15,15,783,
.dw 2498,1666,4467,783,15,15,15,783,
.dw 15,15,15,783,15,15,15,783,
.dw 2354,15,2807,783,15,15,15,783,
.dw 15,15,2807,783,15,15,15,783,
.dw 2498,1666,4467,783,15,15,15,783,
.dw 15,15,15,783,15,15,15,783,
.dw 2354,15,2807,783,15,15,15,783,
.dw 2498,15,2807,783,15,15,15,783,
.dw 15,1666,4467,783,15,15,15,783,
.dw 2354,15,15,783,15,15,15,783,
.dw 15,15,2807,783,15,15,15,783,
.dw 2498,2498,2807,783,15,15,15,783,
.dw 2498,2498,4467,783,15,15,15,783,
.dw 15,2498,15,783,15,15,15,783,
.dw 2354,2498,2807,769,15,15,15,783,
.dw 15,2498,2807,783,15,15,15,783,
; PATTERN 21:
.dw 2226,1666,4467,769,15,15,15,783,
.dw 15,15,15,783,15,15,15,783,
.dw 3330,15,2807,783,15,15,15,783,
.dw 15,15,2807,783,15,15,15,783,
.dw 2226,1666,4467,783,15,15,15,783,
.dw 15,15,15,783,15,15,15,783,
.dw 3330,15,2807,783,15,15,15,783,
.dw 2226,15,2807,783,15,15,15,783,
.dw 15,1666,4467,783,15,15,15,783,
.dw 3330,15,15,783,15,15,15,783,
.dw 15,15,2807,783,15,15,15,783,
.dw 2098,15,2807,783,15,15,15,783,
.dw 2098,1666,4467,783,15,15,15,783,
.dw 2098,15,15,783,15,15,15,783,
.dw 2226,15,2807,783,15,15,15,783,
.dw 15,15,2807,783,15,15,15,783,
.dw 2226,1666,4467,783,15,15,15,783,
.dw 15,15,15,783,15,15,15,783,
.dw 3330,15,2807,783,15,15,15,783,
.dw 15,15,2807,783,15,15,15,783,
.dw 2226,1666,4467,783,15,15,15,783,
.dw 15,15,15,783,15,15,15,783,
.dw 3330,15,2807,783,15,15,15,783,
.dw 2226,15,2807,783,15,15,15,783,
.dw 15,1666,4467,783,15,15,15,783,
.dw 3330,15,15,783,15,15,15,783,
.dw 15,15,2807,783,15,15,15,783,
.dw 2098,1570,2807,783,15,15,15,783,
.dw 2098,1570,1986,783,15,15,15,783,
.dw 2098,1570,15,783,15,15,15,783,
.dw 2226,1570,1986,769,15,15,15,783,
.dw 15,1570,1986,783,15,15,15,783,
; PATTERN 22:
.dw 2226,1666,4467,769,15,15,15,783,
.dw 15,15,15,783,15,15,15,783,
.dw 2098,15,2807,783,15,15,15,783,
.dw 15,15,2807,783,15,15,15,783,
.dw 2226,1666,4467,783,15,15,15,783,
.dw 15,15,15,783,15,15,15,783,
.dw 2098,15,2807,783,15,15,15,783,
.dw 2226,15,2807,783,15,15,15,783,
.dw 15,1666,4467,783,15,15,15,783,
.dw 2098,15,15,783,15,15,15,783,
.dw 15,15,2807,783,15,15,15,783,
.dw 2226,15,2807,783,15,15,15,783,
.dw 2226,1666,4467,783,15,15,15,783,
.dw 15,15,15,783,15,15,15,783,
.dw 2098,15,2807,783,15,15,15,783,
.dw 15,15,2807,783,15,15,15,783,
.dw 2226,1666,4467,783,15,15,15,783,
.dw 15,15,15,783,15,15,15,783,
.dw 2098,15,2807,783,15,15,15,783,
.dw 15,15,2807,783,15,15,15,783,
.dw 2226,1666,4467,783,15,15,15,783,
.dw 15,15,15,783,15,15,15,783,
.dw 2098,15,2807,783,15,15,15,783,
.dw 2226,15,2807,783,15,15,15,783,
.dw 15,1666,4467,783,15,15,15,783,
.dw 2098,15,15,783,15,15,15,783,
.dw 15,15,2807,783,15,15,15,783,
.dw 2226,1570,2807,783,15,15,15,783,
.dw 2226,1570,1986,783,15,15,15,783,
.dw 2226,1570,15,783,15,15,15,783,
.dw 2098,1570,1986,769,15,15,15,783,
.dw 15,1570,1986,783,15,15,15,783,
; PATTERN 23:
.dw 2498,1666,4467,769,15,15,15,783,
.dw 15,15,15,783,15,15,15,783,
.dw 1251,15,2807,783,15,15,15,783,
.dw 15,15,2807,783,15,15,15,783,
.dw 2498,1666,4467,783,15,15,15,783,
.dw 1666,15,15,783,15,15,15,783,
.dw 15,15,2807,783,15,15,15,783,
.dw 2498,15,2807,783,15,15,15,783,
.dw 1570,1666,4467,783,15,15,15,783,
.dw 15,15,15,783,15,15,15,783,
.dw 2498,15,2807,783,15,15,15,783,
.dw 1666,15,2807,783,15,15,15,783,
.dw 15,1666,4467,783,15,15,15,783,
.dw 1394,15,15,783,15,15,15,783,
.dw 1570,15,2807,783,15,15,15,783,
.dw 1666,15,2807,783,15,15,15,783,
.dw 2498,1666,4467,783,15,15,15,783,
.dw 15,15,15,783,15,15,15,783,
.dw 1251,15,2807,783,15,15,15,783,
.dw 15,15,2807,783,15,15,15,783,
.dw 2498,1666,4467,783,15,15,15,783,
.dw 1666,15,15,783,15,15,15,783,
.dw 15,15,2807,783,15,15,15,783,
.dw 2498,15,2807,783,15,15,15,783,
.dw 1570,1666,4467,783,15,15,15,783,
.dw 15,15,15,783,15,15,15,783,
.dw 2498,15,2807,783,15,15,15,783,
.dw 1666,2498,2807,783,15,15,15,783,
.dw 15,2498,4467,783,15,15,15,783,
.dw 2098,2498,15,783,15,15,15,783,
.dw 2226,2498,2807,769,15,15,15,783,
.dw 2498,2498,2807,783,15,15,15,783,
; PATTERN 24:
.dw 2802,1666,4467,769,15,15,15,783,
.dw 15,15,15,783,15,15,15,783,
.dw 1666,15,2807,783,15,15,15,783,
.dw 15,15,2807,783,15,15,15,783,
.dw 2802,1666,4467,783,15,15,15,783,
.dw 2226,15,15,783,15,15,15,783,
.dw 15,15,2807,783,15,15,15,783,
.dw 2802,15,2807,783,15,15,15,783,
.dw 2098,1666,4467,783,15,15,15,783,
.dw 15,15,15,783,15,15,15,783,
.dw 2802,15,2807,783,15,15,15,783,
.dw 2226,15,2807,783,15,15,15,783,
.dw 15,1666,4467,783,15,15,15,783,
.dw 1874,15,15,783,15,15,15,783,
.dw 2098,15,2807,783,15,15,15,783,
.dw 2226,15,2807,783,15,15,15,783,
.dw 2802,1666,4467,783,15,15,15,783,
.dw 15,15,15,783,15,15,15,783,
.dw 1666,15,2807,783,15,15,15,783,
.dw 15,15,2807,783,15,15,15,783,
.dw 2802,1666,4467,783,15,15,15,783,
.dw 2226,15,15,783,15,15,15,783,
.dw 15,15,2807,783,15,15,15,783,
.dw 2802,15,2807,783,15,15,15,783,
.dw 2098,1666,4467,783,15,15,15,783,
.dw 15,15,15,783,15,15,15,783,
.dw 2802,15,2807,783,15,15,15,783,
.dw 2226,1570,2807,783,15,15,15,783,
.dw 15,1570,1986,783,15,15,15,783,
.dw 1874,1570,15,783,15,15,15,783,
.dw 2098,1570,1986,769,15,15,15,783,
.dw 2226,1570,1986,783,15,15,15,783,
; PATTERN 25:
.dw 18882,1666,4467,769,15,15,15,783,
.dw 15,15,15,783,15,15,15,783,
.dw 17634,15,2807,783,15,15,15,783,
.dw 15,15,2807,783,15,15,15,783,
.dw 18882,1666,4467,783,15,15,15,783,
.dw 18050,15,15,783,15,15,15,783,
.dw 15,15,2807,783,15,15,15,783,
.dw 18882,15,2807,783,15,15,15,783,
.dw 17954,1666,4467,783,15,15,15,783,
.dw 15,15,15,783,15,15,15,783,
.dw 18882,15,2807,783,15,15,15,783,
.dw 18050,15,2807,783,15,15,15,783,
.dw 15,1666,4467,783,15,15,15,783,
.dw 17778,15,15,783,15,15,15,783,
.dw 17954,15,2807,783,15,15,15,783,
.dw 18050,15,2807,783,15,15,15,783,
.dw 18882,1666,4467,783,15,15,15,783,
.dw 15,15,15,783,15,15,15,783,
.dw 17634,15,2807,783,15,15,15,783,
.dw 15,15,2807,783,15,15,15,783,
.dw 18882,1666,4467,783,15,15,15,783,
.dw 18050,15,15,783,15,15,15,783,
.dw 15,15,2807,783,15,15,15,783,
.dw 18882,15,2807,783,15,15,15,783,
.dw 17954,1666,4467,783,15,15,15,783,
.dw 15,15,15,783,15,15,15,783,
.dw 18882,15,2807,783,15,15,15,783,
.dw 18050,2498,2807,783,15,15,15,783,
.dw 15,2498,4467,783,15,15,15,783,
.dw 18482,2498,15,783,15,15,15,783,
.dw 18610,2498,2807,769,15,15,15,783,
.dw 18882,2498,2807,783,15,15,15,783,
; PATTERN 26:
.dw 19186,1666,4467,769,15,15,15,783,
.dw 15,15,15,783,15,15,15,783,
.dw 18050,15,2807,783,15,15,15,783,
.dw 15,15,2807,783,15,15,15,783,
.dw 19186,1666,4467,783,15,15,15,783,
.dw 18610,15,15,783,15,15,15,783,
.dw 15,15,2807,783,15,15,15,783,
.dw 19186,15,2807,783,15,15,15,783,
.dw 18482,1666,4467,783,15,15,15,783,
.dw 15,15,15,783,15,15,15,783,
.dw 19186,15,2807,783,15,15,15,783,
.dw 18610,15,2807,783,15,15,15,783,
.dw 15,1666,4467,783,15,15,15,783,
.dw 18258,15,15,783,15,15,15,783,
.dw 18482,15,2807,783,15,15,15,783,
.dw 18610,15,2807,783,15,15,15,783,
.dw 19186,1666,4467,783,15,15,15,783,
.dw 15,15,15,783,15,15,15,783,
.dw 18050,15,2807,783,15,15,15,783,
.dw 15,15,2807,783,15,15,15,783,
.dw 19186,1666,4467,783,15,15,15,783,
.dw 18610,15,15,783,15,15,15,783,
.dw 15,15,2807,783,15,15,15,783,
.dw 19186,15,2807,783,15,15,15,783,
.dw 18482,1666,4467,783,15,15,15,783,
.dw 15,15,15,783,15,15,15,783,
.dw 19186,15,2807,783,15,15,15,783,
.dw 18610,1570,2807,783,15,15,15,783,
.dw 15,1570,1986,783,15,15,15,783,
.dw 18258,1570,15,783,15,15,15,783,
.dw 18482,1570,1986,769,15,15,15,783,
.dw 18610,1570,1986,783,15,15,15,783,
.org $8000
.end
