; Original MOD file: monkey.mod
; Original MOD name: "monkey island       "
; ASM file created by MOD2PSG V1.3 by Martin Konrad (mkon@gmx.de)
; Command line options: -nf 2 

; Constants
RAM_START = $C000

; PSGMOD variables
; (You can place these variables anywhere in RAM.)
PSGMOD_SONG_POSITION    = RAM_START
PSGMOD_PATTERN_POSITION = RAM_START + 1
PSGMOD_PATTERN_ADDRESS  = RAM_START + 2
PSGMOD_CURRENT_SPEED    = RAM_START + 4
PSGMOD_SPEED_COUNTER    = RAM_START + 5
PSGMOD_SONG_START       = RAM_START + 6
PSGMOD_VOL0             = RAM_START + 8
PSGMOD_VOL1             = RAM_START + 9
PSGMOD_VOL2             = RAM_START + 10
PSGMOD_INFO0            = RAM_START + 11
PSGMOD_INFO1            = RAM_START + 12
PSGMOD_INFO2            = RAM_START + 13
; Misc variables
VBLANK_DONE_FLAG        = RAM_START + 14

;==========================================
;=               Start code               =
;==========================================
.org $0000
  di
  im 1
  ld sp, $dff0
  jr START
;-------------------
; VBlank IRQ handler
.org $38
  exx
  ex af, af'
  in a, ($BF)

  ld hl, VBLANK_DONE_FLAG
  inc (HL)

  exx
  ex af, af'
  ei
  reti
;-------------------
; NMI
.org $66
  retn
;-------------------
START:
  call SETUP_FRAMES
  call SET_VDP_REGS_TABLE

;==========================================
;=               Song start               =
;==========================================
    ld hl, PSGMOD_SONG
  call PSGMOD_INITIATE_NEW_SONG
  ei
SONG_LOOP:
    ld d, 1
  call VWAIT

  call PSGMOD_PLAY_NEXT_NOTE

  jr SONG_LOOP
;==========================================
;=              Program end               =
;==========================================

;==========================================
;=            PSG MOD routines            =
;==========================================
; INPUT: HL = address of song
PSGMOD_INITIATE_NEW_SONG:
  ld a, 0
  ld (PSGMOD_SONG_POSITION), a
  ld a, 64
  ld (PSGMOD_PATTERN_POSITION), a
  ld a, 6
  ld (PSGMOD_CURRENT_SPEED), a
  ld (PSGMOD_SPEED_COUNTER), a
  ld a, 15
  ld (PSGMOD_VOL0), a
  ld (PSGMOD_VOL1), a
  ld (PSGMOD_VOL2), a
  ld a, l
  ld (PSGMOD_SONG_START), a
  ld a, h
  ld (PSGMOD_SONG_START + 1), a
  ld ix, (PSGMOD_SONG_START)
  ld a, (IX)
  ld l, a
  ld h, 0
  call HL_512
  ld bc, 128
  add hl, bc
  ld bc, (PSGMOD_SONG_START)
  add hl, bc
  ld a, l
  ld (PSGMOD_PATTERN_ADDRESS), a
  ld a, h
  ld (PSGMOD_PATTERN_ADDRESS+1), a
  ret

PSGMOD_PLAY_NEXT_NOTE:
  ld hl, PSGMOD_SPEED_COUNTER
  dec (HL)
  ret NZ

; Channel 0
    ld ix, (PSGMOD_PATTERN_ADDRESS)
    ld d, 144
    ld hl, PSGMOD_VOL0
  call PSGMOD_SET_VOLUME
    ld hl, PSGMOD_INFO0
    ld d, 128
  call PSGMOD_SET_FREQUENCY

; Channel 1
    ld ix, (PSGMOD_PATTERN_ADDRESS)
    inc ix
    inc ix
    ld d, 176
    ld hl, PSGMOD_VOL1
  call PSGMOD_SET_VOLUME
    ld hl, PSGMOD_INFO1
    ld d, 160
  call PSGMOD_SET_FREQUENCY

; Channel 2
    ld ix, (PSGMOD_PATTERN_ADDRESS)
    inc ix
    inc ix
    inc ix
    inc ix
    ld d, 208
    ld hl, PSGMOD_VOL2
  call PSGMOD_SET_VOLUME
    ld hl, PSGMOD_INFO2
    ld d, 192
  call PSGMOD_SET_FREQUENCY

; Channel 3
  ld hl, (PSGMOD_PATTERN_ADDRESS)
  ld bc, 6
  add hl, bc
  ld b, (HL)

; Set volume of channel 3
  ld a, b
  and 15
  add a, 240
  out ($7F), a

; Set frequeny of channel 3
  ld a, b
  srl a
  srl a
  srl a
  srl a
  add a, 228
  out ($7F), a

; Set speed
  ld hl, (PSGMOD_PATTERN_ADDRESS)
  ld bc, 7
  add hl, bc
  ld c, (HL)
  ld a, c
  and 128
  jr Z, PSGMOD_SET_SPEED
  ld a, 1
  ld (PSGMOD_PATTERN_POSITION), a
PSGMOD_SET_SPEED:
  ld a, c
  and 127
  ld (PSGMOD_CURRENT_SPEED), a
PSGMOD_DONT_SET_SPEED:
  ld a, (PSGMOD_CURRENT_SPEED)
  ld (PSGMOD_SPEED_COUNTER), a

; Next note
  ld hl, (PSGMOD_PATTERN_ADDRESS)
  ld bc, 8
  add hl, bc
  ld (PSGMOD_PATTERN_ADDRESS), hl

  ld hl, PSGMOD_PATTERN_POSITION
  dec (HL)
  ret NZ
  ld a, 64
  ld (PSGMOD_PATTERN_POSITION), a
  ld hl, PSGMOD_SONG_POSITION
  inc (HL)

  call PSGMOD_GET_PATTERN_NUMBER
  bit 7, d
  jr Z, PSGMOD_END_NOT_REACHED

  ld a, d
  and 127
  ld (PSGMOD_SONG_POSITION), a
  call PSGMOD_GET_PATTERN_NUMBER
PSGMOD_END_NOT_REACHED:
  ld h, 0
  ld l, d
  call HL_512
  ld bc, 128
  add hl, bc
  ld bc, (PSGMOD_SONG_START)
  add hl, bc
  ld a, l
  ld (PSGMOD_PATTERN_ADDRESS), a
  ld a, h
  ld (PSGMOD_PATTERN_ADDRESS+1), a
  ret

;==========================================
;=       PSG MOD internal routines        =
;==========================================
PSGMOD_SET_VOLUME:
  ld a, (IX)
  and 15
  cp 15
  jr Z, PSGMOD_FADE_VOL
  ld (HL), a
  add a, d
  out ($7F), a
  ret
PSGMOD_FADE_VOL:
  push hl
  ld bc, 3
  add hl, bc
  ld a, (HL)
  pop hl
  cp 0
  jr Z, PSGMOD_NO_FADE
  ld a, (HL)
  cp 15
  ret Z
  inc a
  ld (HL), a
  add a, d
  out ($7F), a
  ret
PSGMOD_NO_FADE:
  ld a, d
  add a, 15
  out ($7F), a
  ret
PSGMOD_SET_FREQUENCY:
  ld a, (IX)
  and 15
  cp 15
  ret Z
  ld a, (IX)
  srl a
  srl a
  srl a
  srl a
  add a, d
  out ($7F), a
  inc ix
  ld a, (IX)
  out ($7F), a
  bit 6, a
  jr NZ, PSGMOD_SET_FADE_BIT
  ld a, 0
  ld (HL), a
  ret
PSGMOD_SET_FADE_BIT:
  ld a, 1
  ld (HL), a
  ret

PSGMOD_GET_PATTERN_NUMBER:
  ld a, (PSGMOD_SONG_POSITION)
  ld hl, (PSGMOD_SONG_START)
  ld c, a
  ld b, 0
  add hl, bc
  ld d, (HL)
  ret

;==========================================
;=             Misc routines              =
;==========================================
HL_512:
  add hl, hl
  add hl, hl
  add hl, hl
  add hl, hl
  add hl, hl
  add hl, hl
  add hl, hl
  add hl, hl
  add hl, hl
  ret

VWAIT:
  ld a, 0
  ld (VBLANK_DONE_FLAG), a
VWAIT_LOOP:
  ld a, (VBLANK_DONE_FLAG)
  cp d
  ret Z
  jr VWAIT_LOOP

SETUP_FRAMES:
  ld a, 0
  ld ($FFFC), a
  ld ($FFFD), a
  ld a, 1
  ld ($FFFE), a
  ld a, 2
  ld ($FFFF), a
  ret

SET_VDP_REGS_TABLE:
  ld hl, VDP_REGS_TABLE
  ld b, $0f
  ld c, $80
VDP_REGS_LOOP:
  ld a, (HL)
  inc hl
  out ($bf), a
  ld a, c
  inc c
  out ($bf), a
  dec b
  jr NZ, VDP_REGS_LOOP
  ret

VDP_REGS_TABLE:
   .db $06, $60, $FF, $FF, $FF, $FF, $00, $00, $00, $00, $FF, $00, $00, $00, $00, $00

;==========================================
;=               Song data                =
;==========================================

PSGMOD_SONG:

PSGMOD_PATTERN_ORDER:
.db 0,1,2,3,4,5,6,7
.db 8,9,10,11,12,13,14,5
.db 15,16,17,18,19,20,21,22
.db 23,18,19,20,21,22,23,24
.db 25,26,27,28,29,26,27,28
.db 29,30,128,0,0,0,0,0
.db 0,0,0,0,0,0,0,0
.db 0,0,0,0,0,0,0,0
.db 0,0,0,0,0,0,0,0
.db 0,0,0,0,0,0,0,0
.db 0,0,0,0,0,0,0,0
.db 0,0,0,0,0,0,0,0
.db 0,0,0,0,0,0,0,0
.db 0,0,0,0,0,0,0,0
.db 0,0,0,0,0,0,0,0
.db 0,0,0,0,0,0,0,0

PSGMOD_PATTERN_DATA:
; PATTERN 0:
.dw 15,23876,15,1795,15,15,15,1807,
.dw 15,15,15,1807,15,15,15,1807,
.dw 15,15,15,1807,15,15,15,1807,
.dw 15,15,15,1807,15,15,15,1807,
.dw 15,15,15,1807,15,15,15,1807,
.dw 15,15,15,1807,15,15,15,1807,
.dw 15,15,15,1807,15,15,15,1807,
.dw 15,15,15,1807,15,15,15,1807,
.dw 15,15,15,1807,15,15,15,1807,
.dw 15,15,15,1807,15,15,15,1807,
.dw 15,15,15,1807,15,15,15,1807,
.dw 15,15,15,1807,15,15,15,1807,
.dw 15,15,15,1807,15,15,15,1807,
.dw 15,15,15,1807,15,15,15,1807,
.dw 15,15,15,1807,15,15,15,1807,
.dw 15,15,15,1807,15,15,15,1807,
.dw 15,15,18256,1551,15,15,18880,1551,
.dw 15,15,19520,1551,15,15,19712,1807,
.dw 15,15,15,1807,15,15,15,1807,
.dw 15,15,15,2319,15,15,15,2319,
.dw 15,15,20592,1551,15,15,15,1551,
.dw 15,15,15,1807,15,15,15,1807,
.dw 15,15,20128,1551,15,15,15,1551,
.dw 15,15,15,1295,15,15,15,1295,
.dw 15,15,19712,1551,15,15,15,1551,
.dw 15,15,15,1551,15,15,15,1551,
.dw 15,15,20592,1551,15,15,15,1551,
.dw 15,15,15,1295,15,15,15,1295,
.dw 15,15,20128,1551,15,15,15,1551,
.dw 15,15,15,1807,15,15,15,1807,
.dw 15,15,21376,5391,15,15,15,5391,
.dw 15,15,15,5391,15,15,19523,5391,
; PATTERN 1:
.dw 15,22676,19187,2831,15,15,15,2831,
.dw 6294,15,18882,2575,15,15,15,2575,
.dw 6295,15,15,2575,6294,15,15,1551,
.dw 15,15,15,1551,6292,15,15,2575,
.dw 15,15,15,2575,6292,15,15,3087,
.dw 15,15,15,3087,3542,15,15,2575,
.dw 15,15,15,2575,3542,15,15,2575,
.dw 3540,15,15,1551,15,15,15,1551,
.dw 3540,21988,24803,2575,15,15,15,2575,
.dw 3542,15,15,2575,15,15,15,2575,
.dw 3543,15,15,2575,15,15,25315,2575,
.dw 15,15,15,2575,15,15,15,2575,
.dw 15,15,15,2575,15,15,15,2575,
.dw 15,15,15,2575,15,15,15,2575,
.dw 15,15,15,2575,15,15,15,2575,
.dw 15,15,15,2575,15,15,15,2575,
.dw 19524,22676,15,2575,15,15,15,2575,
.dw 15,15,24803,2575,15,15,15,2575,
.dw 15,15,15,2575,15,15,15,2575,
.dw 15,15,15,2575,15,15,15,2575,
.dw 15,15,15,2575,15,15,23875,2575,
.dw 15,15,15,2575,15,15,15,2575,
.dw 15,15,15,2575,15,15,15,2575,
.dw 18884,23060,23059,2575,15,15,15,2575,
.dw 15,15,22675,2575,15,15,15,2575,
.dw 15,15,15,2575,15,15,15,2575,
.dw 15,15,21987,2575,15,15,15,2575,
.dw 18484,24801,15,2575,15,15,15,2575,
.dw 15,15,21379,2575,15,15,15,2575,
.dw 15,15,15,2575,15,15,15,2575,
.dw 15,15,20595,2575,15,15,15,2575,
.dw 15,15,15,2575,15,15,15,2575,
; PATTERN 2:
.dw 23873,18259,15,1025,15,15,15,1039,
.dw 15,20131,15,1029,15,15,15,1039,
.dw 23873,19523,15,1024,15,15,15,1039,
.dw 23873,20131,15,1024,15,15,15,1039,
.dw 15,18883,15,1039,15,15,15,1039,
.dw 15,19523,15,1028,15,15,15,1039,
.dw 15,20131,15,1024,15,15,15,1039,
.dw 15,22675,15,1024,15,15,15,1039,
.dw 15,24803,15,1039,15,15,15,1039,
.dw 15,20595,15,1028,15,15,15,1039,
.dw 24802,19715,15,1024,15,15,15,1039,
.dw 24802,21987,15,1024,15,15,15,1039,
.dw 23874,23875,15,1025,15,15,15,1039,
.dw 15,20131,15,1028,15,15,15,1029,
.dw 23874,19523,15,1024,15,15,15,1039,
.dw 23874,20131,15,1024,15,15,15,1039,
.dw 15,18883,15,1039,15,15,15,1039,
.dw 15,19523,15,1028,15,15,15,1039,
.dw 15,20131,15,1024,15,15,15,1039,
.dw 15,22675,15,1024,15,15,15,1039,
.dw 24802,24803,15,1039,15,15,15,1039,
.dw 15,20595,15,1028,15,15,15,1039,
.dw 24802,19715,15,1024,15,15,15,1039,
.dw 24802,20595,15,1024,15,15,15,-31729,
.dw 15,15,15,1039,15,15,15,1039,
.dw 15,15,15,1039,15,15,15,1039,
.dw 15,15,15,1039,15,15,15,1039,
.dw 15,15,15,1039,15,15,15,1039,
.dw 15,15,15,1039,15,15,15,1039,
.dw 15,15,15,1039,15,15,15,1039,
.dw 15,15,15,1039,15,15,15,1039,
.dw 15,15,15,1039,15,15,15,1039,
; PATTERN 3:
.dw 23873,23875,15,1039,15,15,15,1039,
.dw 23873,20131,15,1028,15,15,15,1039,
.dw 15,19523,15,1024,15,15,15,1039,
.dw 15,20131,15,1024,15,15,15,1039,
.dw 15,21379,20128,1039,15,15,15,1039,
.dw 15,19523,15,1028,15,15,15,1039,
.dw 15,20131,20128,1024,15,15,15,1039,
.dw 15,22675,19520,1024,15,15,15,1039,
.dw 15,24803,19712,1039,15,15,15,1039,
.dw 15,20595,20128,1028,15,15,15,1039,
.dw 24802,19715,20592,1024,15,15,15,1039,
.dw 24802,21987,15,1024,15,15,15,1039,
.dw 21105,25843,20128,1039,15,15,15,1039,
.dw 15,20131,15,1028,15,15,15,1039,
.dw 21105,19523,15,1024,15,15,15,1039,
.dw 21105,18739,15,1024,15,15,15,1039,
.dw 22673,15,15,1026,15,15,15,1039,
.dw 15,15,15,1039,15,15,15,1039,
.dw 22673,22675,20592,1026,15,15,15,1039,
.dw 22673,22675,15,1039,15,15,15,1039,
.dw 15,15,20592,1026,15,15,15,1039,
.dw 15,15,21104,1039,15,15,15,1039,
.dw 15,22675,21376,1026,15,15,15,1039,
.dw 15,22675,20592,1026,15,15,15,1039,
.dw 15,15,21104,1026,15,15,15,1039,
.dw 15,15,15,1039,15,15,15,1039,
.dw 21986,21987,21104,1026,15,15,15,1039,
.dw 21986,21987,15,1039,15,15,15,1039,
.dw 23874,15,21376,1026,15,15,15,1039,
.dw 15,15,15,1039,15,15,15,1039,
.dw 23874,22675,15,1039,15,15,15,1039,
.dw 23874,22675,15,1039,15,15,15,1039,
; PATTERN 4:
.dw 23873,23875,15,1039,15,15,15,1039,
.dw 15,20131,15,1028,15,15,15,1039,
.dw 15,19523,20128,1024,15,15,15,1039,
.dw 15,20131,15,1024,15,15,15,1039,
.dw 15,21379,20128,1039,15,15,15,1039,
.dw 15,19523,15,1028,15,15,15,1039,
.dw 15,20131,20128,1024,15,15,15,1039,
.dw 15,22675,19520,1024,15,15,15,1039,
.dw 20593,24803,19712,1039,15,15,15,1039,
.dw 15,20595,20128,1028,15,15,15,1039,
.dw 20593,19715,20592,1024,15,15,15,1039,
.dw 20593,21987,15,1024,15,15,15,1039,
.dw 21105,25843,20128,1039,15,15,15,1039,
.dw 15,20131,15,1028,15,15,15,1039,
.dw 21105,19523,15,1024,15,15,15,1039,
.dw 21105,18739,15,1024,15,15,15,1039,
.dw 15,15,15,1026,15,15,15,1039,
.dw 15,15,15,1039,15,15,15,1039,
.dw 15,22675,15,1026,15,15,15,1039,
.dw 15,22675,19712,1039,15,15,15,1039,
.dw 22673,15,19520,1026,15,15,15,1039,
.dw 22673,15,15,1039,15,15,15,1039,
.dw 15,21379,19520,1039,15,15,15,1039,
.dw 22673,21379,15,1026,15,15,15,1039,
.dw 21985,15,19184,1026,15,15,15,1039,
.dw 15,15,15,1039,15,15,15,1039,
.dw 21985,21987,15,1026,15,15,15,1039,
.dw 21985,21987,15,1039,15,15,15,1039,
.dw 24801,15,19712,1026,15,15,15,1039,
.dw 24801,18480,15,1039,15,19187,15,1039,
.dw 15,18480,15,1024,15,19187,15,1039,
.dw 15,18480,19520,1024,15,19187,15,1039,
; PATTERN 5:
.dw 15,15,19712,1039,15,15,15,1039,
.dw 15,15,20128,1039,15,15,15,1039,
.dw 15,18480,20592,1024,15,15,15,1039,
.dw 15,15,19712,1024,15,15,15,-31729,
.dw 15,15,15,1039,15,15,15,1039,
.dw 15,15,15,1039,15,15,15,1039,
.dw 15,15,15,1039,15,15,15,1039,
.dw 15,15,15,1039,15,15,15,1039,
.dw 15,15,15,1039,15,15,15,1039,
.dw 15,15,15,1039,15,15,15,1039,
.dw 15,15,15,1039,15,15,15,1039,
.dw 15,15,15,1039,15,15,15,1039,
.dw 15,15,15,1039,15,15,15,1039,
.dw 15,15,15,1039,15,15,15,1039,
.dw 15,15,15,1039,15,15,15,1039,
.dw 15,15,15,1039,15,15,15,1039,
.dw 15,15,20592,1024,15,15,15,1039,
.dw 15,15,19712,1024,15,15,15,-31729,
.dw 15,15,15,1039,15,15,15,1039,
.dw 15,15,15,1039,15,15,15,1039,
.dw 15,15,15,1039,15,15,15,1039,
.dw 15,15,15,1039,15,15,15,1039,
.dw 15,15,15,1039,15,15,15,1039,
.dw 15,15,15,1039,15,15,15,1039,
.dw 15,15,15,1039,15,15,15,1039,
.dw 15,15,15,1039,15,15,15,1039,
.dw 15,15,15,1039,15,15,15,1039,
.dw 15,15,15,1039,15,15,15,1039,
.dw 15,15,15,1039,15,15,15,1039,
.dw 15,15,15,1039,15,15,15,1039,
.dw 15,15,15,1039,15,15,15,1039,
.dw 15,15,15,1039,15,15,15,1039,
; PATTERN 6:
.dw 19521,18883,19520,1039,15,2502,15,1039,
.dw 19521,18883,15,1039,15,2502,15,1039,
.dw 15,18883,19520,1024,15,2502,15,1039,
.dw 19521,2502,15,1024,15,15,15,1039,
.dw 20353,18371,19712,1039,15,1990,15,1039,
.dw 15,18371,15,1028,15,15,15,1039,
.dw 20353,18883,19712,1024,15,2502,15,1039,
.dw 20353,18371,15,1024,15,1990,15,1039,
.dw 20129,18259,20128,1039,15,1878,15,1039,
.dw 20129,18259,15,1028,15,1878,15,1039,
.dw 15,18259,15,1024,15,1878,15,1039,
.dw 15,18259,19520,1024,15,15,15,1039,
.dw 15,18483,19712,1039,15,2102,15,1039,
.dw 15,18483,20128,1028,15,2102,15,1039,
.dw 15,18483,20592,1024,15,2102,15,1039,
.dw 15,15,19712,1024,15,15,15,1039,
.dw 22673,15,19520,1039,15,15,15,1039,
.dw 22673,15,15,1028,15,15,15,1039,
.dw 15,18883,19520,1024,15,15,15,1039,
.dw 22673,18883,15,1024,15,15,15,1039,
.dw 21377,18883,19712,1039,15,2502,15,1039,
.dw 15,18883,15,1028,15,2502,15,1039,
.dw 21377,18739,19712,1024,15,2358,15,1039,
.dw 21377,18371,15,1024,15,1990,15,1039,
.dw 20129,18259,20128,1039,15,1878,15,1039,
.dw 20129,18259,15,1028,15,1878,15,1039,
.dw 15,18259,15,1024,15,1878,15,1039,
.dw 15,15,19520,1024,15,15,15,1039,
.dw 15,18483,19712,1039,15,2102,15,1039,
.dw 15,18483,20128,1028,15,2102,15,1039,
.dw 15,18483,20592,1024,15,2102,15,1039,
.dw 15,15,15,1024,15,15,15,1039,
; PATTERN 7:
.dw 21105,18739,20128,1039,15,2358,15,1039,
.dw 21105,18739,15,1039,15,2358,15,1039,
.dw 15,18739,20128,1024,15,15,15,1039,
.dw 21105,15,15,1024,15,15,15,1039,
.dw 21105,18739,20128,1039,15,2358,15,1039,
.dw 15,18739,15,1028,15,2358,15,1039,
.dw 15,18739,15,1024,15,15,15,1039,
.dw 15,15,15,1024,15,15,15,1039,
.dw 15,15,15,1026,15,15,15,1039,
.dw 15,15,15,1039,15,15,15,1039,
.dw 15,22675,20128,1026,15,15,15,1039,
.dw 15,22675,15,1039,15,15,15,1039,
.dw 22673,15,20592,1026,15,15,15,1039,
.dw 22673,15,21104,1039,15,15,15,1039,
.dw 15,21379,21376,1039,15,15,15,1039,
.dw 22673,21379,20592,1026,15,15,15,1039,
.dw 21985,15,21104,1026,15,15,15,1039,
.dw 15,15,15,1039,15,15,15,1039,
.dw 21985,21987,21104,1026,15,15,15,1039,
.dw 21985,21987,15,1039,15,15,15,-31729,
.dw 23873,15,21376,1026,15,15,15,1039,
.dw 15,15,15,1039,15,15,15,1039,
.dw 15,15,15,1039,15,15,15,1039,
.dw 15,15,15,1039,15,15,15,1039,
.dw 15,15,15,1039,15,15,15,-31729,
.dw 15,15,15,1039,15,15,15,1039,
.dw 15,15,15,1039,15,15,15,1039,
.dw 15,15,15,1039,15,15,15,1039,
.dw 15,15,15,1039,15,15,15,1039,
.dw 15,15,15,1039,15,15,15,1039,
.dw 15,15,15,1039,15,15,15,1039,
.dw 15,15,15,1039,15,15,15,1039,
; PATTERN 8:
.dw 23873,23875,21376,1026,15,15,15,1039,
.dw 15,20131,15,1039,15,15,15,1039,
.dw 23873,19523,15,1024,15,15,15,1039,
.dw 23873,20131,15,1024,15,15,15,1039,
.dw 15,18883,15,1039,15,15,15,1039,
.dw 15,19523,15,1039,15,15,15,1039,
.dw 15,20131,15,1024,15,15,15,1039,
.dw 15,22675,15,1024,15,15,15,1039,
.dw 15,24803,15,1039,15,15,15,1039,
.dw 15,20595,15,1039,15,15,15,1039,
.dw 24802,19715,15,1024,15,15,15,1039,
.dw 24802,21987,15,1024,15,15,15,1039,
.dw 23874,23875,15,1039,15,15,15,1039,
.dw 15,20131,15,1039,15,15,15,1039,
.dw 23874,19523,15,1024,15,15,15,1039,
.dw 23874,20131,15,1024,15,15,15,1039,
.dw 15,21379,15,1039,15,15,15,1039,
.dw 15,19523,15,1039,15,15,15,1039,
.dw 15,20131,15,1024,15,15,15,1039,
.dw 15,22675,15,1024,15,15,15,1039,
.dw 24802,24803,21376,1039,15,15,15,1039,
.dw 15,20595,15,1039,15,15,15,1039,
.dw 24802,19715,20592,1024,15,15,15,1039,
.dw 24802,20595,15,1024,15,15,15,-31729,
.dw 15,15,15,1039,15,15,15,1039,
.dw 15,15,15,1039,15,15,15,1039,
.dw 15,15,15,1039,15,15,15,1039,
.dw 15,15,15,1039,15,15,15,1039,
.dw 15,15,15,1039,15,15,15,1039,
.dw 15,15,15,1039,15,15,15,1039,
.dw 15,15,15,1039,15,15,15,1039,
.dw 15,15,15,1039,15,15,15,1039,
; PATTERN 9:
.dw 21105,15,20128,1026,15,15,15,1039,
.dw 15,15,15,1026,15,15,15,1039,
.dw 21105,19523,19520,1026,15,15,15,1039,
.dw 21105,19523,15,1026,15,15,15,1039,
.dw 15,15,19520,1026,15,15,15,1039,
.dw 15,15,15,1026,15,15,15,1039,
.dw 15,19523,15,1026,15,15,15,1039,
.dw 15,19523,15,1026,15,15,15,1039,
.dw 15,15,21104,1026,15,15,15,1039,
.dw 15,15,18880,1026,15,15,15,1039,
.dw 15,19523,19184,1026,15,15,15,1039,
.dw 15,19523,18736,1026,15,15,15,1039,
.dw 15,15,20592,1026,15,15,15,1039,
.dw 15,15,15,1026,15,15,15,1039,
.dw 22673,20595,19520,1026,15,15,15,1039,
.dw 22673,20595,15,1026,15,15,15,1039,
.dw 21377,15,19520,1026,15,15,15,1039,
.dw 15,15,15,1026,15,15,15,1039,
.dw 20593,20595,15,1026,15,15,15,1039,
.dw 15,20595,15,1026,15,15,15,1039,
.dw 15,15,21376,1026,15,15,15,1039,
.dw 15,15,15,1026,15,15,15,1039,
.dw 15,20595,19520,1026,15,15,15,1039,
.dw 15,20595,15,1026,15,15,15,-31729,
.dw 15,15,15,1026,15,15,15,1039,
.dw 15,15,15,1026,15,15,15,1039,
.dw 15,15,15,1026,15,15,15,1039,
.dw 15,15,15,1026,15,15,15,1039,
.dw 15,15,15,1026,15,15,15,1039,
.dw 15,15,15,1026,15,15,15,1039,
.dw 15,15,15,1026,15,15,15,1039,
.dw 15,15,15,1026,15,15,15,1039,
; PATTERN 10:
.dw 21105,15,21104,1026,15,15,15,1039,
.dw 15,15,15,1026,15,15,15,1039,
.dw 24801,18739,20592,1026,15,15,15,1039,
.dw 24801,18739,15,1026,15,15,15,1039,
.dw 23057,15,20592,1026,15,15,15,1039,
.dw 15,15,15,1026,15,15,15,1039,
.dw 21985,18739,15,1026,15,15,15,1039,
.dw 15,18739,19184,1026,15,15,15,1039,
.dw 20593,15,20592,1026,15,15,15,1039,
.dw 15,15,19184,1026,15,15,15,1039,
.dw 15,18739,19520,1026,15,15,15,1039,
.dw 15,18739,19184,1026,15,15,15,1039,
.dw 20129,15,19520,1026,15,15,15,1039,
.dw 20129,15,15,1026,15,15,15,1039,
.dw 20129,20131,19712,1026,15,15,15,1039,
.dw 15,20131,15,1026,15,15,15,1039,
.dw 21377,15,20128,1026,15,15,15,1039,
.dw 15,15,15,1026,15,15,15,1039,
.dw 22673,20131,21376,1026,15,15,15,1039,
.dw 15,20131,15,1026,15,15,15,1039,
.dw 23873,15,21376,1026,15,15,15,1039,
.dw 15,15,15,1026,15,15,15,1039,
.dw 15,20131,15,1026,15,15,15,1039,
.dw 15,20131,15,1026,15,15,15,1039,
.dw 15,15,23056,1026,15,15,15,1039,
.dw 15,15,15,1026,15,15,15,1039,
.dw 23873,20131,22672,1026,15,15,15,1039,
.dw 23873,20131,15,1026,15,15,15,-31729,
.dw 15,15,15,1039,15,15,15,1039,
.dw 15,15,15,1039,15,15,15,1039,
.dw 15,20131,15,1039,15,15,15,1039,
.dw 15,20131,15,1039,15,15,15,1039,
; PATTERN 11:
.dw 23457,15,19189,1024,15,15,15,1039,
.dw 15,19923,15,1039,15,15,15,1039,
.dw 21985,18147,15,1024,15,15,15,1039,
.dw 15,18739,15,1024,15,15,15,1039,
.dw 21105,18739,15,1039,15,15,15,1039,
.dw 15,19187,15,1039,15,15,15,1039,
.dw 15,18147,15,1039,15,15,15,1039,
.dw 15,17779,15,1039,15,15,15,1039,
.dw 15,19923,15,1039,15,15,15,1039,
.dw 15,19187,15,1039,15,15,15,1039,
.dw 15,18147,15,1024,15,15,15,1039,
.dw 15,19923,15,1024,15,15,15,1039,
.dw 15,18739,15,1039,15,15,15,1039,
.dw 15,18739,15,1039,15,15,15,1039,
.dw 19921,17779,15,1039,15,15,15,1039,
.dw 19921,18147,15,1039,15,15,15,1039,
.dw 20129,15,19525,1026,15,15,15,1039,
.dw 15,15,15,1039,15,15,15,1039,
.dw 21377,19523,15,1026,15,15,15,1039,
.dw 15,19523,15,1039,15,15,15,1039,
.dw 22673,15,15,1026,15,15,15,1039,
.dw 15,15,15,1039,15,15,15,1039,
.dw 15,19523,15,1039,15,15,15,1039,
.dw 15,19523,15,1026,15,15,15,1039,
.dw 15,15,15,1026,15,15,15,1039,
.dw 15,15,15,1039,15,15,15,1039,
.dw 15,19523,15,1026,15,15,15,1039,
.dw 15,19523,15,1039,15,15,15,1039,
.dw 22673,15,15,1026,22673,15,15,1039,
.dw 22673,15,15,1026,15,15,15,1039,
.dw 22673,19523,20133,1026,15,15,15,1039,
.dw 23873,19523,15,1026,15,15,15,1039,
; PATTERN 12:
.dw 22673,15,19525,1039,15,15,15,1039,
.dw 15,21107,15,1039,15,15,15,1039,
.dw 21377,18739,15,1024,15,15,15,1039,
.dw 15,19523,15,1024,15,15,15,1039,
.dw 20593,17955,15,1039,15,15,15,1039,
.dw 15,20355,15,1039,15,15,15,1039,
.dw 15,18483,15,1024,15,15,15,1039,
.dw 15,18371,15,1024,15,15,15,1039,
.dw 15,21107,18741,1039,15,15,15,1039,
.dw 15,19523,15,1039,15,15,15,1039,
.dw 15,18739,15,1024,15,15,15,1039,
.dw 15,20355,15,1024,15,15,15,1039,
.dw 15,17955,15,1039,15,15,15,1039,
.dw 15,19523,15,1039,15,15,15,1039,
.dw 19521,18371,15,1024,15,15,15,1039,
.dw 19521,18739,15,1039,15,15,15,1039,
.dw 19713,15,18485,1026,15,15,15,1039,
.dw 15,15,15,1039,15,15,15,1039,
.dw 20593,20595,15,1026,15,15,15,1039,
.dw 15,20595,15,1039,15,15,15,1039,
.dw 21985,15,15,1026,15,15,15,1039,
.dw 15,15,15,1039,15,15,15,1039,
.dw 15,20595,15,1039,15,15,15,1039,
.dw 15,20595,15,1026,15,15,15,1039,
.dw 15,15,15,1026,15,15,15,1039,
.dw 15,15,15,1039,15,15,15,1039,
.dw 15,20595,15,1026,15,15,15,1039,
.dw 15,20595,15,1039,15,15,15,1039,
.dw 15,15,15,1026,15,15,15,1039,
.dw 15,15,15,1026,15,15,15,1039,
.dw 20593,20595,15,1026,15,15,15,1039,
.dw 20593,20595,15,1039,15,15,15,1039,
; PATTERN 13:
.dw 20129,4724,20128,1026,15,15,15,1039,
.dw 15,15,15,1039,15,15,15,1039,
.dw 20129,22675,20128,1024,15,15,15,1039,
.dw 20129,19523,19520,1024,15,15,15,1039,
.dw 15,20595,19712,1039,15,15,15,1039,
.dw 15,21987,20128,1039,15,15,15,1039,
.dw 20593,23059,20592,1024,15,15,15,1039,
.dw 20593,19715,15,1024,15,15,15,1039,
.dw 21105,19523,20128,1039,15,15,15,1039,
.dw 21105,22675,15,1039,15,15,15,1039,
.dw 15,19523,15,1024,15,15,15,1039,
.dw 21105,15,15,1024,15,15,15,1039,
.dw 22673,15,15,1026,15,15,15,1039,
.dw 15,15,15,1026,15,15,15,1039,
.dw 22673,19523,20592,1026,15,15,15,1039,
.dw 22673,19523,15,1026,15,15,15,1039,
.dw 15,15,20592,1026,15,15,15,1039,
.dw 15,15,21104,1026,15,15,15,1039,
.dw 15,19523,21376,1026,15,15,15,1039,
.dw 15,19523,20592,1026,15,15,15,1039,
.dw 21985,15,21104,1026,15,15,15,1039,
.dw 21985,15,15,1026,15,15,15,1039,
.dw 15,19187,21104,1026,15,15,15,1039,
.dw 21985,19187,15,1026,15,15,15,1039,
.dw 23873,15,21376,1026,15,15,15,1039,
.dw 15,15,15,1026,15,15,15,1039,
.dw 23873,19523,15,1026,15,15,15,1039,
.dw 23873,19523,15,1026,15,15,15,1039,
.dw 15,15,15,1039,15,15,15,1039,
.dw 15,15,15,1039,15,15,15,-31729,
.dw 15,15,15,1039,15,15,15,1039,
.dw 15,15,15,1039,15,15,15,1039,
; PATTERN 14:
.dw 15,22675,20128,1024,15,15,15,1039,
.dw 15,19523,15,1024,15,15,15,1039,
.dw 15,20131,20128,1039,15,15,15,1039,
.dw 15,21379,15,1028,15,15,15,1039,
.dw 20129,20131,15,1024,15,15,15,1039,
.dw 20129,20131,19520,1024,15,15,15,1039,
.dw 20593,20595,19712,1039,15,15,15,1039,
.dw 20593,19187,20128,1028,15,15,15,1039,
.dw 15,20131,20592,1024,15,15,15,1039,
.dw 20593,18883,15,1024,15,15,15,1039,
.dw 21105,18739,20128,1039,15,15,15,1039,
.dw 15,19523,15,1028,15,15,15,1039,
.dw 21105,20131,15,1024,15,15,15,1039,
.dw 21105,15,15,1024,15,15,15,1039,
.dw 15,15,15,1026,15,15,15,1039,
.dw 15,15,15,1026,15,15,15,1039,
.dw 15,21107,15,1026,15,15,15,1039,
.dw 15,21107,19712,1026,15,15,15,1039,
.dw 22673,15,19520,1026,15,15,15,1039,
.dw 22673,15,15,1026,15,15,15,1039,
.dw 15,21379,19520,1026,15,15,15,1039,
.dw 22673,21379,15,1026,15,15,15,1039,
.dw 21985,15,19184,1026,15,15,15,1039,
.dw 15,15,15,1026,15,15,15,1039,
.dw 21985,21107,15,1026,15,15,15,1039,
.dw 21985,21107,15,1026,15,15,15,1039,
.dw 24801,19187,19712,1026,15,2807,15,1039,
.dw 24801,19187,15,1026,15,2807,15,1039,
.dw 15,19187,15,1026,15,2807,15,1039,
.dw 15,19187,19520,1039,15,2807,15,1039,
.dw 15,19187,19712,1039,15,15,15,1039,
.dw 15,15,20128,1039,15,15,15,-31729,
; PATTERN 15:
.dw 19521,18883,19520,1039,15,2502,15,1039,
.dw 19521,18883,15,1039,15,2502,15,1039,
.dw 15,18883,19520,1024,15,2502,15,1039,
.dw 19521,2502,15,1024,15,15,15,1039,
.dw 20353,18371,19712,1039,15,1990,15,1039,
.dw 15,18371,15,1039,15,1990,15,1039,
.dw 20353,18371,15,1024,15,1990,15,1039,
.dw 20353,1990,15,1024,15,15,15,1039,
.dw 20129,18259,20128,1039,15,1878,15,1039,
.dw 20129,18259,15,1039,15,1878,15,1039,
.dw 15,18259,15,1024,15,1878,15,1039,
.dw 15,18259,19520,1024,15,15,15,1039,
.dw 15,15,19712,1039,15,15,15,1039,
.dw 15,15,20128,1039,15,15,15,1039,
.dw 15,18483,20592,1024,15,2102,15,1039,
.dw 15,18483,19712,1024,15,2102,15,1039,
.dw 22673,18883,19520,1039,15,2502,15,1039,
.dw 22673,18883,15,1039,15,2502,15,1039,
.dw 15,18883,19520,1024,15,2502,15,1039,
.dw 22673,2502,15,1024,15,15,15,1039,
.dw 21377,1990,19712,1039,15,18371,15,1039,
.dw 15,1990,15,1039,15,18371,15,1039,
.dw 21377,1990,19712,1024,15,1990,15,1039,
.dw 21377,15,15,1024,15,15,15,1039,
.dw 20129,18259,20128,1039,15,1878,15,1039,
.dw 20129,18259,15,1039,15,1878,15,1039,
.dw 15,18259,15,1024,15,1878,15,1039,
.dw 15,18259,19520,1024,15,15,15,1039,
.dw 15,15,19712,1039,15,15,15,1039,
.dw 15,15,20128,1039,15,15,15,1039,
.dw 15,18483,20592,1024,15,2102,15,1039,
.dw 15,18483,15,1024,15,2102,15,1039,
; PATTERN 16:
.dw 21105,18739,20128,1039,15,2358,15,1039,
.dw 21105,18739,15,1039,15,2358,15,1039,
.dw 15,18739,20128,1024,15,2358,15,1039,
.dw 21105,18739,15,1024,15,2358,15,1039,
.dw 21105,1767,20128,1026,15,15,15,1039,
.dw 15,15,15,1039,15,15,15,1039,
.dw 15,15,15,1026,15,15,15,1039,
.dw 15,15,15,1026,15,15,15,1039,
.dw 22673,19523,15,1026,15,15,15,1039,
.dw 22673,15,15,1039,15,15,15,1039,
.dw 15,19523,20592,1026,15,15,15,1039,
.dw 22673,19523,15,1026,15,15,15,1039,
.dw 21985,15,21104,1026,15,15,15,1039,
.dw 15,15,21376,1026,15,15,15,1039,
.dw 21985,19187,21104,1026,15,15,15,1039,
.dw 21985,19187,15,1026,15,15,15,1039,
.dw 23873,15,21376,1026,15,15,15,1039,
.dw 15,23875,15,1039,15,15,15,1039,
.dw 23873,20595,15,1024,15,15,15,1039,
.dw 23873,20131,15,1024,15,15,15,1039,
.dw 15,19715,15,1039,15,15,15,1039,
.dw 15,23875,15,1039,15,15,15,1039,
.dw 15,21987,20128,1024,15,15,15,1039,
.dw 15,19187,15,1024,15,15,15,1039,
.dw 15,18883,20128,1039,15,2502,15,1039,
.dw 15,18883,15,1039,15,2502,15,1039,
.dw 15,18883,15,1024,15,2502,15,1039,
.dw 15,18883,19520,1024,15,2502,15,1039,
.dw 15,2499,19712,1039,15,15,15,1039,
.dw 15,2803,20128,1039,15,15,15,1039,
.dw 20593,15,20592,1024,15,15,15,1039,
.dw 20593,3139,15,1024,15,15,15,1039,
; PATTERN 17:
.dw 21105,19523,20128,1039,15,3142,15,1039,
.dw 21105,19523,15,1039,15,3142,15,1039,
.dw 15,19523,20128,1024,15,3142,15,1039,
.dw 21105,19523,15,1024,15,3142,15,1039,
.dw 21105,3142,20128,1026,15,15,15,1039,
.dw 15,15,15,1026,15,15,15,1039,
.dw 15,15,15,1026,15,15,15,1039,
.dw 15,15,19520,1026,15,15,15,1039,
.dw 20593,15,19184,1026,15,15,15,1039,
.dw 20593,15,19520,1026,15,15,15,1039,
.dw 15,21987,19712,1026,15,15,15,1039,
.dw 20593,21987,19184,1026,15,15,15,1039,
.dw 21105,15,19520,1026,15,15,15,1039,
.dw 15,15,20128,1026,15,15,15,1039,
.dw 20593,15,19712,1026,15,15,15,1039,
.dw 20593,15,15,1039,15,15,15,1039,
.dw 23873,15,20128,1026,15,15,15,1039,
.dw 15,15,15,1039,15,15,15,1039,
.dw 15,15,15,1039,15,15,15,1039,
.dw 15,15,15,1039,15,15,15,1039,
.dw 15,15,15,1039,15,15,15,1039,
.dw 15,15,15,1039,15,15,15,1039,
.dw 15,15,15,1039,15,15,15,1039,
.dw 15,15,15,1039,15,15,15,1039,
.dw 15,15,15,1039,15,15,15,1039,
.dw 15,15,15,1039,15,15,15,1039,
.dw 15,15,15,1039,15,15,15,1039,
.dw 15,15,15,1039,15,15,15,1039,
.dw 15,15,15,1039,15,15,15,1039,
.dw 15,15,15,1039,15,15,15,1039,
.dw 15,15,15,1039,15,15,15,1039,
.dw 15,15,15,1039,15,15,15,1039,
; PATTERN 18:
.dw 22673,19522,15,1039,15,15,15,1039,
.dw 15,15,22675,1039,15,15,15,1039,
.dw 21681,15,19523,1039,15,15,15,1039,
.dw 15,19522,20595,1025,15,15,15,1039,
.dw 24801,19026,15,1039,15,15,15,1039,
.dw 15,15,22675,1039,15,15,15,1039,
.dw 15,18482,19523,1025,15,15,15,1039,
.dw 15,15,20595,1039,15,15,15,1039,
.dw 15,18610,15,1039,15,15,15,1039,
.dw 15,15,21987,1039,15,15,15,1039,
.dw 21985,18610,19187,1025,15,15,15,1039,
.dw 15,15,20131,1025,15,15,15,1039,
.dw 15,19186,15,1029,15,15,15,1039,
.dw 15,15,21987,1039,15,15,15,1039,
.dw 20129,15,19187,1025,15,15,15,1039,
.dw 15,15,20131,1039,15,15,15,1039,
.dw 15,20354,15,1029,15,15,15,1039,
.dw 15,15,22675,1039,15,15,15,1039,
.dw 21681,20354,19523,1025,15,15,15,1039,
.dw 15,15,20355,1029,15,15,15,1039,
.dw 24337,20354,15,1039,15,15,15,1039,
.dw 15,15,22675,1039,15,15,15,1039,
.dw 15,15,19523,1025,15,15,15,1039,
.dw 15,15,20355,1039,15,15,15,1039,
.dw 15,20594,15,1026,15,15,15,1039,
.dw 15,15,24803,1039,15,15,15,1039,
.dw 4721,20594,19715,1039,15,15,15,1039,
.dw 24801,15,20595,1025,15,15,15,1039,
.dw 21985,20594,15,1039,15,15,15,1039,
.dw 15,15,24803,1039,15,15,15,1039,
.dw 20593,15,19715,1025,15,15,15,1039,
.dw 15,15,20595,1039,15,15,15,1039,
; PATTERN 19:
.dw 22673,19522,15,1039,15,15,15,1039,
.dw 15,15,22675,1039,15,15,15,1039,
.dw 21681,15,19523,1039,15,15,15,1039,
.dw 15,19522,20595,1025,15,15,15,1039,
.dw 24801,19026,15,1039,15,15,15,1039,
.dw 15,15,22675,1039,15,15,15,1039,
.dw 15,18482,19523,1025,15,15,15,1039,
.dw 15,15,20595,1039,15,15,15,1039,
.dw 15,18258,15,1039,15,15,15,1039,
.dw 15,15,21987,1039,15,15,15,1039,
.dw 21985,18258,19187,1025,15,15,15,1039,
.dw 15,15,20131,1025,15,15,15,1039,
.dw 15,18610,15,1029,15,15,15,1039,
.dw 15,15,21987,1039,15,15,15,1039,
.dw 20129,15,19187,1025,15,15,15,1039,
.dw 15,15,20131,1039,15,15,15,1039,
.dw 15,21106,15,1029,15,15,15,1039,
.dw 15,15,22675,1039,15,15,15,1039,
.dw 21681,21106,19523,1025,15,15,15,1039,
.dw 15,15,20355,1029,15,15,15,1039,
.dw 24337,21106,15,1039,15,15,15,1039,
.dw 15,15,22675,1039,15,15,15,1039,
.dw 15,21106,19523,1025,15,15,15,1039,
.dw 15,15,20355,1039,15,15,15,1039,
.dw 15,20594,15,1029,15,15,15,1039,
.dw 15,15,24803,1039,15,15,15,1039,
.dw 4721,15,19715,1039,15,15,15,1039,
.dw 24801,15,20595,1025,15,15,15,1039,
.dw 21985,15,15,1039,15,15,15,1039,
.dw 15,15,24803,1039,15,15,15,1039,
.dw 20593,15,19715,1025,15,15,15,1039,
.dw 15,15,20595,1039,15,15,15,1039,
; PATTERN 20:
.dw 22673,19522,15,1039,15,15,15,1039,
.dw 15,15,22675,1039,15,15,15,1039,
.dw 21681,15,19523,1039,15,15,15,1039,
.dw 15,19522,20595,1025,15,15,15,1039,
.dw 24801,19026,15,1039,15,15,15,1039,
.dw 15,15,22675,1039,15,15,15,1039,
.dw 15,18482,19523,1025,15,15,15,1039,
.dw 15,15,20595,1039,15,15,15,1039,
.dw 15,18610,15,1039,15,15,15,1039,
.dw 15,15,21987,1039,15,15,15,1039,
.dw 21985,18610,19187,1025,15,15,15,1039,
.dw 15,15,20131,1025,15,15,15,1039,
.dw 15,19186,15,1029,15,15,15,1039,
.dw 15,15,21987,1039,15,15,15,1039,
.dw 20129,15,19187,1025,15,15,15,1039,
.dw 15,15,20131,1039,15,15,15,1039,
.dw 15,21106,15,1027,15,15,15,1039,
.dw 15,15,22675,1039,15,15,15,1039,
.dw 21681,21106,19523,1025,15,15,15,1039,
.dw 15,15,20355,1027,15,15,15,1039,
.dw 24337,21106,15,1039,15,15,15,1039,
.dw 15,15,22675,1039,15,15,15,1039,
.dw 15,21682,19523,1025,15,15,15,1039,
.dw 15,15,20355,1039,15,15,15,1039,
.dw 15,22674,15,1027,15,15,15,1039,
.dw 15,15,22675,1039,15,15,15,1039,
.dw 4721,15,19523,1039,15,15,15,1039,
.dw 24801,22674,20595,1025,15,15,15,1039,
.dw 21985,22674,15,1039,15,15,15,1039,
.dw 15,15,22675,1039,15,15,15,1039,
.dw 20593,15,19523,1025,15,15,15,1039,
.dw 15,15,20595,1039,15,15,15,1039,
; PATTERN 21:
.dw 20353,19522,15,1039,15,15,15,1039,
.dw 15,15,22675,1039,15,15,15,1039,
.dw 15,19522,19523,1039,15,15,15,1039,
.dw 15,15,20595,1027,15,15,4726,1039,
.dw 21681,19186,15,1025,15,15,15,1039,
.dw 15,15,22675,1039,15,15,15,1039,
.dw 20353,19026,19523,1039,15,15,15,1039,
.dw 15,15,20595,1039,15,15,15,1039,
.dw 15,19186,15,1027,15,15,15,1039,
.dw 15,15,21987,1039,15,15,15,1039,
.dw 15,19714,19187,1025,15,15,15,1039,
.dw 15,15,20131,1025,15,15,15,1039,
.dw 21985,20594,15,1026,15,15,15,1039,
.dw 15,15,21987,1039,15,15,15,1039,
.dw 20593,20594,19187,1025,15,15,15,1039,
.dw 15,15,20131,1039,15,15,15,1039,
.dw 25841,21106,15,1039,15,15,15,1039,
.dw 15,15,24339,1039,15,15,15,1039,
.dw 25841,15,20355,1025,15,15,15,1039,
.dw 25841,21106,24339,1025,15,15,15,1039,
.dw 22673,20594,15,1039,15,15,15,1039,
.dw 15,15,24339,1039,15,15,15,1039,
.dw 25841,20354,20355,1025,15,15,15,1039,
.dw 15,15,20355,1039,15,15,15,1039,
.dw 24801,20594,15,1039,15,15,15,1039,
.dw 15,15,24803,1039,15,15,15,1039,
.dw 15,15,19715,1025,15,15,15,1039,
.dw 24801,15,20595,1025,15,15,15,1039,
.dw 21985,20594,15,1039,15,15,15,1039,
.dw 15,15,24803,1039,15,15,15,1039,
.dw 24801,15,19715,1025,15,15,15,1039,
.dw 15,20594,20595,1039,15,15,15,1039,
; PATTERN 22:
.dw 15,21106,15,1029,15,15,15,1039,
.dw 15,15,25843,1039,15,15,15,1039,
.dw 21105,15,21107,1039,15,15,15,1039,
.dw 4721,21106,21107,1026,15,15,15,1039,
.dw 20353,20594,15,1025,15,15,15,1039,
.dw 15,15,25843,1039,15,15,15,1039,
.dw 21105,20354,21107,1039,15,15,15,1039,
.dw 15,15,21107,1039,15,15,15,1039,
.dw 15,20594,15,1029,15,15,15,1039,
.dw 15,15,24803,1039,15,15,15,1039,
.dw 21985,15,20595,1039,15,15,15,1039,
.dw 15,15,20595,1026,15,15,15,1039,
.dw 20593,20594,15,1029,15,15,15,1039,
.dw 15,21106,24803,1039,15,15,15,1039,
.dw 15,21682,20355,1025,15,15,15,1039,
.dw 15,21986,20595,1039,15,15,15,1039,
.dw 4721,22674,15,1029,15,15,15,1039,
.dw 15,15,22675,1039,15,15,15,1039,
.dw 20593,15,19523,1025,15,15,15,1039,
.dw 15,15,20595,1025,15,15,15,1039,
.dw 19521,15,15,1039,15,15,15,1039,
.dw 15,15,22675,1039,15,15,15,1039,
.dw 15,22674,19523,1025,15,15,15,1039,
.dw 15,20594,20595,1039,15,15,15,1039,
.dw 20353,19522,15,1039,15,15,15,1039,
.dw 20353,15,22675,1039,15,15,15,1039,
.dw 15,19522,19523,1025,15,15,15,1039,
.dw 20353,15,20595,1025,15,15,15,1039,
.dw 20593,19714,15,1039,15,15,15,1039,
.dw 15,15,22675,1039,15,15,15,1039,
.dw 15,19714,19523,1025,15,15,15,1039,
.dw 15,15,20595,1039,15,15,15,1039,
; PATTERN 23:
.dw 22673,19522,15,1039,15,15,15,1039,
.dw 15,15,22675,1039,15,15,15,1039,
.dw 20593,15,19523,1025,15,15,15,1039,
.dw 15,15,20595,1026,15,15,4726,1039,
.dw 19521,15,15,1039,15,15,15,1039,
.dw 15,15,22675,1039,15,15,15,1039,
.dw 15,15,19523,1026,15,15,15,1039,
.dw 15,15,20595,1039,15,15,15,1039,
.dw 19521,15,15,1039,15,15,15,1039,
.dw 15,15,22675,1039,15,15,15,1039,
.dw 15,19522,19523,1025,15,15,15,1039,
.dw 19521,15,20595,1025,15,15,15,1039,
.dw 20593,15,15,1039,15,15,15,1039,
.dw 15,19522,22675,1039,15,15,15,1039,
.dw 21681,15,19523,1025,15,15,15,1039,
.dw 15,15,20595,1039,15,15,15,1039,
.dw 22673,19522,15,1039,15,15,15,1039,
.dw 15,15,22675,1039,15,15,15,1039,
.dw 20593,15,19523,1025,15,15,15,1039,
.dw 15,19522,20595,1025,15,15,15,1039,
.dw 19521,15,15,1039,15,15,15,1039,
.dw 15,15,22675,1039,15,15,15,1039,
.dw 15,15,19523,1025,15,15,15,1039,
.dw 15,15,20595,1039,15,15,15,1039,
.dw 19521,15,15,1039,15,15,15,1039,
.dw 15,15,22675,1039,15,15,15,1039,
.dw 15,19522,19523,1025,15,15,15,1039,
.dw 19521,15,20595,1025,15,15,15,1039,
.dw 20593,15,15,1039,15,15,15,1039,
.dw 15,19522,22675,1039,15,15,15,1039,
.dw 21681,15,19523,1025,15,15,15,1039,
.dw 15,15,20595,1039,15,15,15,1039,
; PATTERN 24:
.dw 22673,19522,15,1039,15,15,15,1039,
.dw 15,15,22674,1039,15,15,15,1039,
.dw 19521,15,19523,1039,15,15,15,1039,
.dw 15,19522,20596,1039,15,15,15,1039,
.dw 20593,19522,15,1039,15,15,15,1039,
.dw 15,15,22677,1039,15,15,15,1039,
.dw 21681,15,19525,1039,15,15,15,1039,
.dw 15,15,20607,1039,15,15,15,1039,
.dw 22673,15,15,1039,15,15,15,1039,
.dw 15,15,15,1039,15,15,15,1039,
.dw 15,15,15,1039,15,15,15,1039,
.dw 15,15,15,1039,15,15,15,1039,
.dw 15,15,15,1039,15,15,15,1039,
.dw 15,15,15,1039,15,15,15,1039,
.dw 15,15,15,1039,15,15,15,1039,
.dw 15,15,15,1039,15,15,15,1039,
.dw 15,15,15,1039,15,15,15,1039,
.dw 15,15,15,271,15,15,15,271,
.dw 15,15,15,271,15,15,15,271,
.dw 15,15,15,271,15,15,15,271,
.dw 15,15,15,271,15,15,15,271,
.dw 15,15,15,271,15,15,15,271,
.dw 15,15,15,271,15,15,15,271,
.dw 15,15,15,271,15,15,15,271,
.dw 15,15,15,271,15,15,15,271,
.dw 15,15,15,271,15,15,15,271,
.dw 15,15,15,271,15,15,15,271,
.dw 15,15,15,271,15,15,15,271,
.dw 15,15,15,271,15,15,15,271,
.dw 15,15,15,271,15,15,15,271,
.dw 15,15,15,271,15,15,15,271,
.dw 15,15,15,271,15,15,15,271,
; PATTERN 25:
.dw 23457,3539,23458,1026,15,15,15,1039,
.dw 15,4727,15,1039,15,15,15,1039,
.dw 19921,2359,23458,1027,15,15,15,1039,
.dw 19921,3539,19922,1027,15,15,15,1039,
.dw 15,2359,15,1028,15,15,15,1039,
.dw 15,3539,23458,1027,15,15,15,1039,
.dw 15,3539,19922,1028,15,15,15,1039,
.dw 15,4728,15,1039,15,15,4726,1039,
.dw 23457,3539,3141,1039,15,15,4212,1039,
.dw 19921,3539,4722,1026,15,15,15,1039,
.dw 15,4723,15,1039,15,15,15,1039,
.dw 23457,15,15,1039,15,15,15,1039,
.dw 23873,3539,23874,1026,15,15,15,1039,
.dw 15,4726,15,1039,15,15,15,1039,
.dw 20129,2358,23874,1039,15,15,15,1039,
.dw 20129,3539,20130,1039,15,15,15,1039,
.dw 15,2358,15,1039,15,15,15,1039,
.dw 15,3539,23874,1039,15,15,15,1039,
.dw 15,3539,20130,1039,15,15,15,1039,
.dw 15,4727,15,1039,15,15,15,1039,
.dw 23873,3539,3138,1039,15,15,3142,1039,
.dw 20129,3539,3141,1039,15,15,3140,1039,
.dw 15,4723,3746,1039,15,15,4994,1039,
.dw 23873,6291,7074,1039,15,15,15,-31729,
.dw 15,15,15,1039,15,15,15,1039,
.dw 15,15,15,1039,15,15,15,1039,
.dw 15,15,15,1039,15,15,15,1039,
.dw 15,15,15,1039,15,15,15,1039,
.dw 15,15,15,1039,15,15,15,1039,
.dw 15,15,15,1039,15,15,15,1039,
.dw 15,15,15,1039,15,15,15,1039,
.dw 15,15,15,1039,15,15,15,1039,
; PATTERN 26:
.dw 21104,1985,25841,1795,15,15,15,1807,
.dw 15,15,25841,1795,22672,1985,21105,1795,
.dw 21104,15,15,1807,20592,1985,21105,1795,
.dw 20352,1985,24337,1807,15,15,15,1807,
.dw 15,15,15,1795,20592,1985,22673,1795,
.dw 15,15,15,1807,15,1985,15,1795,
.dw 21104,1985,15,1807,15,15,15,1807,
.dw 15,15,23457,1795,22672,1985,19921,1795,
.dw 21104,15,15,1807,20352,1985,19921,1795,
.dw 19520,1985,22321,1807,15,15,15,1807,
.dw 15,15,15,1795,19920,1985,21105,1795,
.dw 15,15,15,1807,15,1985,15,1795,
.dw 20352,1985,15,1807,15,15,15,1807,
.dw 15,15,25841,1795,15,1985,21105,1795,
.dw 15,15,15,1807,15,1985,21105,1795,
.dw 19520,1985,24337,1807,15,15,15,1807,
.dw 15,15,15,1795,15,1985,22673,1795,
.dw 15,15,15,1807,21104,1985,15,1795,
.dw 20848,1985,15,1807,15,15,15,1807,
.dw 20352,15,25313,1795,19920,1985,20849,1795,
.dw 15,15,15,1807,18880,1985,20849,1795,
.dw 15,1985,23457,1807,15,15,15,1807,
.dw 15,15,15,1795,15,1985,22321,1795,
.dw 15,15,15,1807,15,1985,15,-30973,
.dw 15,1985,15,-30961,15,15,15,-30961,
.dw 15,15,15,1807,15,15,15,1807,
.dw 15,15,15,1807,15,15,15,1807,
.dw 15,15,15,1807,15,15,15,1807,
.dw 15,15,15,1807,15,15,15,1807,
.dw 15,15,15,1807,15,15,15,1807,
.dw 15,15,15,1807,15,15,15,1807,
.dw 15,15,15,1807,15,15,15,1807,
; PATTERN 27:
.dw 21104,1985,15,1807,15,15,15,1807,
.dw 15,15,25841,1795,22672,1985,21105,1795,
.dw 21104,15,15,1807,20592,1985,21105,1795,
.dw 20352,1985,24337,1807,15,15,15,1807,
.dw 15,15,15,1795,20592,1985,22673,1795,
.dw 15,15,15,1807,15,1985,15,1795,
.dw 21104,1985,15,1807,15,15,15,1807,
.dw 15,15,22321,1795,22672,1985,15,1795,
.dw 21104,15,15,1807,20352,1985,19713,1795,
.dw 19520,1985,15,1807,15,15,15,1807,
.dw 15,15,19921,1795,19920,1985,20353,1795,
.dw 15,15,15,1807,15,1985,15,1795,
.dw 20352,1985,15,1807,15,15,15,1807,
.dw 19520,15,22673,1795,15,1985,15,1795,
.dw 15,15,15,1807,15,1985,22673,1795,
.dw 18736,1985,15,1807,15,15,15,1807,
.dw 18368,15,22673,1795,15,1985,15,1795,
.dw 15,15,15,1807,15,1985,15,-30973,
.dw 18736,1985,15,-30961,15,15,15,1807,
.dw 15,15,21105,-30973,15,1985,21105,-30973,
.dw 15,15,15,1807,15,1985,15,1795,
.dw 15,1985,15,1807,15,15,15,1807,
.dw 15,15,15,1795,15,1985,15,1795,
.dw 15,15,15,1807,15,1985,15,1795,
.dw 15,1985,15,-30961,15,15,15,-30961,
.dw 15,15,15,1807,15,15,15,1807,
.dw 15,15,15,1807,15,15,15,1807,
.dw 15,15,15,1807,15,15,15,1807,
.dw 15,15,15,1807,15,15,15,1807,
.dw 15,15,15,1807,15,15,15,1807,
.dw 15,15,15,1807,15,15,15,1807,
.dw 15,15,15,1807,15,15,15,1807,
; PATTERN 28:
.dw 18736,1985,15,1792,15,15,15,1807,
.dw 15,15,21105,1792,15,1985,24337,1792,
.dw 15,15,15,1807,15,1985,24337,1792,
.dw 15,1985,22673,1792,15,15,15,1807,
.dw 15,15,15,1792,21106,1985,21105,1792,
.dw 15,15,15,1807,21106,1985,15,1792,
.dw 15,1985,15,1792,15,15,15,1807,
.dw 15,15,22321,1792,15,1985,15,1792,
.dw 15,15,15,1807,15,1985,22321,1792,
.dw 15,1985,24337,1792,15,15,15,1807,
.dw 15,15,15,1792,15,1985,22321,1792,
.dw 15,15,15,1807,15,1985,15,1792,
.dw 15,1985,15,1792,15,15,15,1807,
.dw 15,15,25841,1792,15,1985,15,1792,
.dw 15,15,15,1807,15,1985,25841,1792,
.dw 15,1985,24337,1792,15,15,15,1807,
.dw 15,15,15,1792,21106,1985,22673,1792,
.dw 15,15,15,1807,21106,1985,15,1792,
.dw 15,1985,15,1792,15,15,15,1807,
.dw 15,15,15,1792,15,1985,22321,1792,
.dw 15,15,15,1807,15,1985,22321,1792,
.dw 15,1985,24337,1792,15,15,15,1807,
.dw 15,15,15,1792,15,1985,22321,1792,
.dw 15,15,15,1807,15,1985,15,-30976,
.dw 15,1985,15,1792,15,15,15,1807,
.dw 15,15,15,-30961,15,15,15,1807,
.dw 15,15,15,1807,15,15,15,1807,
.dw 15,15,15,1807,15,15,15,1807,
.dw 15,15,15,1807,15,15,15,1807,
.dw 15,15,15,1807,15,15,15,1807,
.dw 15,15,15,1807,15,15,15,1807,
.dw 15,15,15,1807,15,15,15,1807,
; PATTERN 29:
.dw 15,1985,15,1792,15,15,15,1807,
.dw 15,15,25841,1792,15,1985,15,1792,
.dw 15,15,15,1807,15,1985,25841,1792,
.dw 15,1985,24337,1792,15,15,15,1807,
.dw 15,15,15,1792,21106,1985,22673,1792,
.dw 15,15,15,1807,19714,1985,15,1792,
.dw 15,1985,15,1792,15,15,15,1807,
.dw 15,15,22321,1792,15,1985,15,1792,
.dw 15,15,15,1807,15,1985,22321,1792,
.dw 15,1985,24337,1792,15,15,15,1807,
.dw 15,15,15,1792,15,1985,25841,1792,
.dw 15,15,15,1807,19714,1985,15,1792,
.dw 19522,1985,15,1792,15,15,15,1807,
.dw 15,15,15,1792,15,1985,22673,1792,
.dw 15,15,15,1807,15,1985,22673,1792,
.dw 19522,1985,24337,1792,15,15,15,1807,
.dw 15,15,15,1792,20352,1985,25841,1792,
.dw 15,15,15,1807,20592,1985,15,1792,
.dw 15,1985,15,1792,15,15,15,1807,
.dw 15,15,22673,1792,15,1985,15,1792,
.dw 15,15,15,1807,15,1985,22673,1792,
.dw 15,1985,24801,1792,15,15,15,1807,
.dw 15,15,15,1792,15,1985,22673,1792,
.dw 15,15,15,1807,15,1985,15,1792,
.dw 15,1985,15,1792,15,15,15,1807,
.dw 15,15,15,-30976,15,15,15,1807,
.dw 15,15,15,1807,15,15,15,1807,
.dw 15,15,15,1807,15,15,15,1807,
.dw 15,15,15,1807,15,15,15,1807,
.dw 15,15,15,1807,15,15,15,1807,
.dw 15,15,15,1807,15,15,15,1807,
.dw 15,15,15,1807,15,15,15,1807,
; PATTERN 30:
.dw 21107,1985,25841,1792,15,15,15,1807,
.dw 15,1988,15,1807,15,15,15,1807,
.dw 15,1989,15,1807,15,15,15,1807,
.dw 15,15,15,1807,15,15,15,1807,
.dw 15,15,15,1807,15,15,15,1807,
.dw 15,15,15,1807,15,15,15,1807,
.dw 15,15,15,1807,15,15,15,1807,
.dw 15,15,15,1807,15,15,15,1807,
.dw 15,15,15,1807,15,15,15,1807,
.dw 15,15,15,-30961,15,15,15,1807,
.dw 15,15,15,1807,15,15,15,1807,
.dw 15,15,15,1807,15,15,15,1807,
.dw 15,15,15,1807,15,15,15,1807,
.dw 15,15,15,1807,15,15,15,1807,
.dw 15,15,15,1807,15,15,15,1807,
.dw 15,15,15,1807,15,15,15,1807,
.dw 15,15,15,1807,15,15,15,1807,
.dw 15,15,15,1807,15,15,15,1807,
.dw 15,15,15,1807,15,15,15,1807,
.dw 15,15,15,1807,15,15,15,1807,
.dw 15,15,15,1807,15,15,15,1807,
.dw 15,15,15,1807,15,15,15,1807,
.dw 15,15,15,1807,15,15,15,1807,
.dw 15,15,15,1807,15,15,15,1807,
.dw 15,15,15,1807,15,15,15,1807,
.dw 15,15,15,1807,15,15,15,1807,
.dw 15,15,15,1807,15,15,15,1807,
.dw 15,15,15,1807,15,15,15,1807,
.dw 15,15,15,1807,15,15,15,1807,
.dw 15,15,15,1807,15,15,15,1807,
.dw 15,15,15,1807,15,15,15,1807,
.dw 15,15,15,1807,15,15,15,1807,
.org $8000
.end
